Class: Zyphr::AuthEmailOTPApi

Inherits:
Object
  • Object
show all
Defined in:
lib/zyphr/api/auth_email_otp_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AuthEmailOTPApi

Returns a new instance of AuthEmailOTPApi.



19
20
21
# File 'lib/zyphr/api/auth_email_otp_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/zyphr/api/auth_email_otp_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#check_email_otp_availability(opts = {}) ⇒ CheckEmailOtpAvailability200Response

Check email OTP availability Check if numeric email OTP authentication is available for this application. Requires a verified sending domain on the project.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



26
27
28
29
# File 'lib/zyphr/api/auth_email_otp_api.rb', line 26

def check_email_otp_availability(opts = {})
  data, _status_code, _headers = check_email_otp_availability_with_http_info(opts)
  data
end

#check_email_otp_availability_with_http_info(opts = {}) ⇒ Array<(CheckEmailOtpAvailability200Response, Integer, Hash)>

Check email OTP availability Check if numeric email OTP authentication is available for this application. Requires a verified sending domain on the project.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/zyphr/api/auth_email_otp_api.rb', line 35

def check_email_otp_availability_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuthEmailOTPApi.check_email_otp_availability ...'
  end
  # resource path
  local_var_path = '/auth/email-otp/available'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CheckEmailOtpAvailability200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApplicationPublicKey']

  new_options = opts.merge(
    :operation => :"AuthEmailOTPApi.check_email_otp_availability",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuthEmailOTPApi#check_email_otp_availability\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#send_email_otp_login(send_email_otp_registration_request, opts = {}) ⇒ PhoneOtpSentResponse

Send email OTP for login Send a numeric verification code to an existing user's email address for login.

Parameters:

Returns:



84
85
86
87
# File 'lib/zyphr/api/auth_email_otp_api.rb', line 84

def (send_email_otp_registration_request, opts = {})
  data, _status_code, _headers = (send_email_otp_registration_request, opts)
  data
end

#send_email_otp_login_with_http_info(send_email_otp_registration_request, opts = {}) ⇒ Array<(PhoneOtpSentResponse, Integer, Hash)>

Send email OTP for login Send a numeric verification code to an existing user's email address for login.

Parameters:

Returns:

  • (Array<(PhoneOtpSentResponse, Integer, Hash)>)

    PhoneOtpSentResponse data, response status code and response headers



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/zyphr/api/auth_email_otp_api.rb', line 94

def (send_email_otp_registration_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuthEmailOTPApi.send_email_otp_login ...'
  end
  # verify the required parameter 'send_email_otp_registration_request' is set
  if @api_client.config.client_side_validation && send_email_otp_registration_request.nil?
    fail ArgumentError, "Missing the required parameter 'send_email_otp_registration_request' when calling AuthEmailOTPApi.send_email_otp_login"
  end
  # resource path
  local_var_path = '/auth/email-otp/login/send'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(send_email_otp_registration_request)

  # return_type
  return_type = opts[:debug_return_type] || 'PhoneOtpSentResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'ApplicationPublicKey']

  new_options = opts.merge(
    :operation => :"AuthEmailOTPApi.send_email_otp_login",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuthEmailOTPApi#send_email_otp_login\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#send_email_otp_registration(send_email_otp_registration_request, opts = {}) ⇒ PhoneOtpSentResponse

Send email OTP for registration Send a numeric verification code to an email address for new user registration.

Parameters:

Returns:



152
153
154
155
# File 'lib/zyphr/api/auth_email_otp_api.rb', line 152

def send_email_otp_registration(send_email_otp_registration_request, opts = {})
  data, _status_code, _headers = send_email_otp_registration_with_http_info(send_email_otp_registration_request, opts)
  data
end

#send_email_otp_registration_with_http_info(send_email_otp_registration_request, opts = {}) ⇒ Array<(PhoneOtpSentResponse, Integer, Hash)>

Send email OTP for registration Send a numeric verification code to an email address for new user registration.

Parameters:

Returns:

  • (Array<(PhoneOtpSentResponse, Integer, Hash)>)

    PhoneOtpSentResponse data, response status code and response headers



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/zyphr/api/auth_email_otp_api.rb', line 162

def send_email_otp_registration_with_http_info(send_email_otp_registration_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuthEmailOTPApi.send_email_otp_registration ...'
  end
  # verify the required parameter 'send_email_otp_registration_request' is set
  if @api_client.config.client_side_validation && send_email_otp_registration_request.nil?
    fail ArgumentError, "Missing the required parameter 'send_email_otp_registration_request' when calling AuthEmailOTPApi.send_email_otp_registration"
  end
  # resource path
  local_var_path = '/auth/email-otp/register/send'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(send_email_otp_registration_request)

  # return_type
  return_type = opts[:debug_return_type] || 'PhoneOtpSentResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'ApplicationPublicKey']

  new_options = opts.merge(
    :operation => :"AuthEmailOTPApi.send_email_otp_registration",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuthEmailOTPApi#send_email_otp_registration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#verify_email_otp_login(verify_email_otp_login_request, opts = {}) ⇒ AuthLoginResponse

Verify email OTP login Verify the numeric code and login an existing user. If MFA is enabled, returns mfa_required with a challenge token.

Parameters:

Returns:



220
221
222
223
# File 'lib/zyphr/api/auth_email_otp_api.rb', line 220

def (, opts = {})
  data, _status_code, _headers = (, opts)
  data
end

#verify_email_otp_login_with_http_info(verify_email_otp_login_request, opts = {}) ⇒ Array<(AuthLoginResponse, Integer, Hash)>

Verify email OTP login Verify the numeric code and login an existing user. If MFA is enabled, returns mfa_required with a challenge token.

Parameters:

Returns:

  • (Array<(AuthLoginResponse, Integer, Hash)>)

    AuthLoginResponse data, response status code and response headers



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/zyphr/api/auth_email_otp_api.rb', line 230

def (, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuthEmailOTPApi.verify_email_otp_login ...'
  end
  # verify the required parameter 'verify_email_otp_login_request' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'verify_email_otp_login_request' when calling AuthEmailOTPApi.verify_email_otp_login"
  end
  # resource path
  local_var_path = '/auth/email-otp/login/verify'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body()

  # return_type
  return_type = opts[:debug_return_type] || 'AuthLoginResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'ApplicationPublicKey']

  new_options = opts.merge(
    :operation => :"AuthEmailOTPApi.verify_email_otp_login",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuthEmailOTPApi#verify_email_otp_login\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#verify_email_otp_registration(verify_email_otp_registration_request, opts = {}) ⇒ AuthResultResponse

Verify email OTP registration Verify the numeric code and create a new user account with the email address.

Parameters:

Returns:



288
289
290
291
# File 'lib/zyphr/api/auth_email_otp_api.rb', line 288

def verify_email_otp_registration(verify_email_otp_registration_request, opts = {})
  data, _status_code, _headers = verify_email_otp_registration_with_http_info(verify_email_otp_registration_request, opts)
  data
end

#verify_email_otp_registration_with_http_info(verify_email_otp_registration_request, opts = {}) ⇒ Array<(AuthResultResponse, Integer, Hash)>

Verify email OTP registration Verify the numeric code and create a new user account with the email address.

Parameters:

Returns:

  • (Array<(AuthResultResponse, Integer, Hash)>)

    AuthResultResponse data, response status code and response headers



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/zyphr/api/auth_email_otp_api.rb', line 298

def verify_email_otp_registration_with_http_info(verify_email_otp_registration_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuthEmailOTPApi.verify_email_otp_registration ...'
  end
  # verify the required parameter 'verify_email_otp_registration_request' is set
  if @api_client.config.client_side_validation && verify_email_otp_registration_request.nil?
    fail ArgumentError, "Missing the required parameter 'verify_email_otp_registration_request' when calling AuthEmailOTPApi.verify_email_otp_registration"
  end
  # resource path
  local_var_path = '/auth/email-otp/register/verify'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(verify_email_otp_registration_request)

  # return_type
  return_type = opts[:debug_return_type] || 'AuthResultResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'ApplicationPublicKey']

  new_options = opts.merge(
    :operation => :"AuthEmailOTPApi.verify_email_otp_registration",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuthEmailOTPApi#verify_email_otp_registration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end