Class: Zyphr::AuthMagicLinksApi
- Inherits:
-
Object
- Object
- Zyphr::AuthMagicLinksApi
- Defined in:
- lib/zyphr/api/auth_magic_links_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ AuthMagicLinksApi
constructor
A new instance of AuthMagicLinksApi.
-
#send_magic_link(magic_link_send_request, opts = {}) ⇒ SuccessResult
Send a magic link Send a magic link email for passwordless authentication.
-
#send_magic_link_with_http_info(magic_link_send_request, opts = {}) ⇒ Array<(SuccessResult, Integer, Hash)>
Send a magic link Send a magic link email for passwordless authentication.
-
#verify_magic_link(magic_link_verify_request, opts = {}) ⇒ MagicLinkVerifyResponse
Verify a magic link Verify a magic link token and authenticate the user.
-
#verify_magic_link_with_http_info(magic_link_verify_request, opts = {}) ⇒ Array<(MagicLinkVerifyResponse, Integer, Hash)>
Verify a magic link Verify a magic link token and authenticate the user.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AuthMagicLinksApi
Returns a new instance of AuthMagicLinksApi.
19 20 21 |
# File 'lib/zyphr/api/auth_magic_links_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zyphr/api/auth_magic_links_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#send_magic_link(magic_link_send_request, opts = {}) ⇒ SuccessResult
Send a magic link Send a magic link email for passwordless authentication.
27 28 29 30 |
# File 'lib/zyphr/api/auth_magic_links_api.rb', line 27 def send_magic_link(magic_link_send_request, opts = {}) data, _status_code, _headers = send_magic_link_with_http_info(magic_link_send_request, opts) data end |
#send_magic_link_with_http_info(magic_link_send_request, opts = {}) ⇒ Array<(SuccessResult, Integer, Hash)>
Send a magic link Send a magic link email for passwordless authentication.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zyphr/api/auth_magic_links_api.rb', line 37 def send_magic_link_with_http_info(magic_link_send_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthMagicLinksApi.send_magic_link ...' end # verify the required parameter 'magic_link_send_request' is set if @api_client.config.client_side_validation && magic_link_send_request.nil? fail ArgumentError, "Missing the required parameter 'magic_link_send_request' when calling AuthMagicLinksApi.send_magic_link" end # resource path local_var_path = '/auth/magic-link/send' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(magic_link_send_request) # return_type return_type = opts[:debug_return_type] || 'SuccessResult' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthMagicLinksApi.send_magic_link", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthMagicLinksApi#send_magic_link\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#verify_magic_link(magic_link_verify_request, opts = {}) ⇒ MagicLinkVerifyResponse
Verify a magic link Verify a magic link token and authenticate the user. Returns auth result with is_new_user flag.
95 96 97 98 |
# File 'lib/zyphr/api/auth_magic_links_api.rb', line 95 def verify_magic_link(magic_link_verify_request, opts = {}) data, _status_code, _headers = verify_magic_link_with_http_info(magic_link_verify_request, opts) data end |
#verify_magic_link_with_http_info(magic_link_verify_request, opts = {}) ⇒ Array<(MagicLinkVerifyResponse, Integer, Hash)>
Verify a magic link Verify a magic link token and authenticate the user. Returns auth result with is_new_user flag.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/zyphr/api/auth_magic_links_api.rb', line 105 def verify_magic_link_with_http_info(magic_link_verify_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthMagicLinksApi.verify_magic_link ...' end # verify the required parameter 'magic_link_verify_request' is set if @api_client.config.client_side_validation && magic_link_verify_request.nil? fail ArgumentError, "Missing the required parameter 'magic_link_verify_request' when calling AuthMagicLinksApi.verify_magic_link" end # resource path local_var_path = '/auth/magic-link/verify' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(magic_link_verify_request) # return_type return_type = opts[:debug_return_type] || 'MagicLinkVerifyResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthMagicLinksApi.verify_magic_link", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthMagicLinksApi#verify_magic_link\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |