Class: Zyphr::AuthMethods
- Inherits:
-
Object
- Object
- Zyphr::AuthMethods
- Defined in:
- lib/zyphr/models/auth_methods.rb
Overview
Aggregate view of the sign-in methods configured for a single end user, for building a customer "sign-in methods" screen.
Instance Attribute Summary collapse
-
#email_verified ⇒ Object
True if the user's email address has been verified.
-
#has_password ⇒ Object
True if the user has a password credential (false for OAuth-only / passwordless users).
-
#mfa_enabled ⇒ Object
True if the user has multi-factor authentication enabled.
-
#oauth_providers ⇒ Object
Distinct OAuth providers linked to the user (e.g. google, apple).
-
#passkeys ⇒ Object
Number of WebAuthn passkeys registered for the user.
-
#phone_verified ⇒ Object
True if the user's phone number has been verified.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthMethods
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AuthMethods
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/zyphr/models/auth_methods.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zyphr::AuthMethods` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zyphr::AuthMethods`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'has_password') self.has_password = attributes[:'has_password'] else self.has_password = nil end if attributes.key?(:'oauth_providers') if (value = attributes[:'oauth_providers']).is_a?(Array) self.oauth_providers = value end else self.oauth_providers = nil end if attributes.key?(:'mfa_enabled') self.mfa_enabled = attributes[:'mfa_enabled'] else self.mfa_enabled = nil end if attributes.key?(:'email_verified') self.email_verified = attributes[:'email_verified'] else self.email_verified = nil end if attributes.key?(:'phone_verified') self.phone_verified = attributes[:'phone_verified'] else self.phone_verified = nil end if attributes.key?(:'passkeys') self.passkeys = attributes[:'passkeys'] else self.passkeys = nil end end |
Instance Attribute Details
#email_verified ⇒ Object
True if the user's email address has been verified.
29 30 31 |
# File 'lib/zyphr/models/auth_methods.rb', line 29 def email_verified @email_verified end |
#has_password ⇒ Object
True if the user has a password credential (false for OAuth-only / passwordless users).
20 21 22 |
# File 'lib/zyphr/models/auth_methods.rb', line 20 def has_password @has_password end |
#mfa_enabled ⇒ Object
True if the user has multi-factor authentication enabled.
26 27 28 |
# File 'lib/zyphr/models/auth_methods.rb', line 26 def mfa_enabled @mfa_enabled end |
#oauth_providers ⇒ Object
Distinct OAuth providers linked to the user (e.g. google, apple).
23 24 25 |
# File 'lib/zyphr/models/auth_methods.rb', line 23 def oauth_providers @oauth_providers end |
#passkeys ⇒ Object
Number of WebAuthn passkeys registered for the user.
35 36 37 |
# File 'lib/zyphr/models/auth_methods.rb', line 35 def passkeys @passkeys end |
#phone_verified ⇒ Object
True if the user's phone number has been verified.
32 33 34 |
# File 'lib/zyphr/models/auth_methods.rb', line 32 def phone_verified @phone_verified end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/zyphr/models/auth_methods.rb', line 289 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Zyphr.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/zyphr/models/auth_methods.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/zyphr/models/auth_methods.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/zyphr/models/auth_methods.rb', line 38 def self.attribute_map { :'has_password' => :'has_password', :'oauth_providers' => :'oauth_providers', :'mfa_enabled' => :'mfa_enabled', :'email_verified' => :'email_verified', :'phone_verified' => :'phone_verified', :'passkeys' => :'passkeys' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/zyphr/models/auth_methods.rb', line 265 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/zyphr/models/auth_methods.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/zyphr/models/auth_methods.rb', line 60 def self.openapi_types { :'has_password' => :'Boolean', :'oauth_providers' => :'Array<String>', :'mfa_enabled' => :'Boolean', :'email_verified' => :'Boolean', :'phone_verified' => :'Boolean', :'passkeys' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
239 240 241 242 243 244 245 246 247 248 |
# File 'lib/zyphr/models/auth_methods.rb', line 239 def ==(o) return true if self.equal?(o) self.class == o.class && has_password == o.has_password && oauth_providers == o.oauth_providers && mfa_enabled == o.mfa_enabled && email_verified == o.email_verified && phone_verified == o.phone_verified && passkeys == o.passkeys end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/zyphr/models/auth_methods.rb', line 360 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
252 253 254 |
# File 'lib/zyphr/models/auth_methods.rb', line 252 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
258 259 260 |
# File 'lib/zyphr/models/auth_methods.rb', line 258 def hash [has_password, oauth_providers, mfa_enabled, email_verified, phone_verified, passkeys].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/zyphr/models/auth_methods.rb', line 134 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @has_password.nil? invalid_properties.push('invalid value for "has_password", has_password cannot be nil.') end if @oauth_providers.nil? invalid_properties.push('invalid value for "oauth_providers", oauth_providers cannot be nil.') end if @mfa_enabled.nil? invalid_properties.push('invalid value for "mfa_enabled", mfa_enabled cannot be nil.') end if @email_verified.nil? invalid_properties.push('invalid value for "email_verified", email_verified cannot be nil.') end if @phone_verified.nil? invalid_properties.push('invalid value for "phone_verified", phone_verified cannot be nil.') end if @passkeys.nil? invalid_properties.push('invalid value for "passkeys", passkeys cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
336 337 338 |
# File 'lib/zyphr/models/auth_methods.rb', line 336 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/zyphr/models/auth_methods.rb', line 342 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
330 331 332 |
# File 'lib/zyphr/models/auth_methods.rb', line 330 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
166 167 168 169 170 171 172 173 174 175 |
# File 'lib/zyphr/models/auth_methods.rb', line 166 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @has_password.nil? return false if @oauth_providers.nil? return false if @mfa_enabled.nil? return false if @email_verified.nil? return false if @phone_verified.nil? return false if @passkeys.nil? true end |