Class: Zyphr::AuthPasswordResetApi
- Inherits:
-
Object
- Object
- Zyphr::AuthPasswordResetApi
- Defined in:
- lib/zyphr/api/auth_password_reset_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#forgot_password(forgot_password_request, opts = {}) ⇒ SuccessResult
Request a password reset Request a password reset email.
-
#forgot_password_with_http_info(forgot_password_request, opts = {}) ⇒ Array<(SuccessResult, Integer, Hash)>
Request a password reset Request a password reset email.
-
#initialize(api_client = ApiClient.default) ⇒ AuthPasswordResetApi
constructor
A new instance of AuthPasswordResetApi.
-
#reset_end_user_password(reset_password_request, opts = {}) ⇒ ResetPasswordResponse
Reset password Reset a user’s password using a valid reset token.
-
#reset_end_user_password_with_http_info(reset_password_request, opts = {}) ⇒ Array<(ResetPasswordResponse, Integer, Hash)>
Reset password Reset a user's password using a valid reset token.
-
#validate_reset_token(validate_reset_token_request, opts = {}) ⇒ ValidateResetTokenResponse
Validate a password reset token Validate a password reset token without consuming it.
-
#validate_reset_token_with_http_info(validate_reset_token_request, opts = {}) ⇒ Array<(ValidateResetTokenResponse, Integer, Hash)>
Validate a password reset token Validate a password reset token without consuming it.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AuthPasswordResetApi
Returns a new instance of AuthPasswordResetApi.
19 20 21 |
# File 'lib/zyphr/api/auth_password_reset_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zyphr/api/auth_password_reset_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#forgot_password(forgot_password_request, opts = {}) ⇒ SuccessResult
Request a password reset Request a password reset email. Creates a reset token and sends an email to the user. Always returns success to prevent email enumeration.
27 28 29 30 |
# File 'lib/zyphr/api/auth_password_reset_api.rb', line 27 def forgot_password(forgot_password_request, opts = {}) data, _status_code, _headers = forgot_password_with_http_info(forgot_password_request, opts) data end |
#forgot_password_with_http_info(forgot_password_request, opts = {}) ⇒ Array<(SuccessResult, Integer, Hash)>
Request a password reset Request a password reset email. Creates a reset token and sends an email to the user. Always returns success to prevent email enumeration.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zyphr/api/auth_password_reset_api.rb', line 37 def forgot_password_with_http_info(forgot_password_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthPasswordResetApi.forgot_password ...' end # verify the required parameter 'forgot_password_request' is set if @api_client.config.client_side_validation && forgot_password_request.nil? fail ArgumentError, "Missing the required parameter 'forgot_password_request' when calling AuthPasswordResetApi.forgot_password" end # resource path local_var_path = '/auth/forgot-password' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(forgot_password_request) # return_type return_type = opts[:debug_return_type] || 'SuccessResult' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthPasswordResetApi.forgot_password", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthPasswordResetApi#forgot_password\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#reset_end_user_password(reset_password_request, opts = {}) ⇒ ResetPasswordResponse
Reset password Reset a user’s password using a valid reset token.
95 96 97 98 |
# File 'lib/zyphr/api/auth_password_reset_api.rb', line 95 def reset_end_user_password(reset_password_request, opts = {}) data, _status_code, _headers = reset_end_user_password_with_http_info(reset_password_request, opts) data end |
#reset_end_user_password_with_http_info(reset_password_request, opts = {}) ⇒ Array<(ResetPasswordResponse, Integer, Hash)>
Reset password Reset a user's password using a valid reset token.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/zyphr/api/auth_password_reset_api.rb', line 105 def reset_end_user_password_with_http_info(reset_password_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthPasswordResetApi.reset_end_user_password ...' end # verify the required parameter 'reset_password_request' is set if @api_client.config.client_side_validation && reset_password_request.nil? fail ArgumentError, "Missing the required parameter 'reset_password_request' when calling AuthPasswordResetApi.reset_end_user_password" end # resource path local_var_path = '/auth/reset-password' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(reset_password_request) # return_type return_type = opts[:debug_return_type] || 'ResetPasswordResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthPasswordResetApi.reset_end_user_password", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthPasswordResetApi#reset_end_user_password\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_reset_token(validate_reset_token_request, opts = {}) ⇒ ValidateResetTokenResponse
Validate a password reset token Validate a password reset token without consuming it. Useful for checking if a token is valid before showing the reset form.
163 164 165 166 |
# File 'lib/zyphr/api/auth_password_reset_api.rb', line 163 def validate_reset_token(validate_reset_token_request, opts = {}) data, _status_code, _headers = validate_reset_token_with_http_info(validate_reset_token_request, opts) data end |
#validate_reset_token_with_http_info(validate_reset_token_request, opts = {}) ⇒ Array<(ValidateResetTokenResponse, Integer, Hash)>
Validate a password reset token Validate a password reset token without consuming it. Useful for checking if a token is valid before showing the reset form.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/zyphr/api/auth_password_reset_api.rb', line 173 def validate_reset_token_with_http_info(validate_reset_token_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthPasswordResetApi.validate_reset_token ...' end # verify the required parameter 'validate_reset_token_request' is set if @api_client.config.client_side_validation && validate_reset_token_request.nil? fail ArgumentError, "Missing the required parameter 'validate_reset_token_request' when calling AuthPasswordResetApi.validate_reset_token" end # resource path local_var_path = '/auth/validate-reset-token' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(validate_reset_token_request) # return_type return_type = opts[:debug_return_type] || 'ValidateResetTokenResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthPasswordResetApi.validate_reset_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthPasswordResetApi#validate_reset_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |