Class: Zyphr::EmailMessage

Inherits:
Object
  • Object
show all
Defined in:
lib/zyphr/models/email_message.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EmailMessage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/zyphr/models/email_message.rb', line 133

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zyphr::EmailMessage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zyphr::EmailMessage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'status_reason')
    self.status_reason = attributes[:'status_reason']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'queued_at')
    self.queued_at = attributes[:'queued_at']
  end

  if attributes.key?(:'sent_at')
    self.sent_at = attributes[:'sent_at']
  end

  if attributes.key?(:'delivered_at')
    self.delivered_at = attributes[:'delivered_at']
  end

  if attributes.key?(:'bounced_at')
    self.bounced_at = attributes[:'bounced_at']
  end

  if attributes.key?(:'opened_at')
    self.opened_at = attributes[:'opened_at']
  end

  if attributes.key?(:'clicked_at')
    self.clicked_at = attributes[:'clicked_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#bounced_atObject

Returns the value of attribute bounced_at.



39
40
41
# File 'lib/zyphr/models/email_message.rb', line 39

def bounced_at
  @bounced_at
end

#clicked_atObject

Returns the value of attribute clicked_at.



43
44
45
# File 'lib/zyphr/models/email_message.rb', line 43

def clicked_at
  @clicked_at
end

#created_atObject

Returns the value of attribute created_at.



45
46
47
# File 'lib/zyphr/models/email_message.rb', line 45

def created_at
  @created_at
end

#delivered_atObject

Returns the value of attribute delivered_at.



37
38
39
# File 'lib/zyphr/models/email_message.rb', line 37

def delivered_at
  @delivered_at
end

#fromObject

Returns the value of attribute from.



20
21
22
# File 'lib/zyphr/models/email_message.rb', line 20

def from
  @from
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zyphr/models/email_message.rb', line 18

def id
  @id
end

#opened_atObject

Returns the value of attribute opened_at.



41
42
43
# File 'lib/zyphr/models/email_message.rb', line 41

def opened_at
  @opened_at
end

#queued_atObject

Returns the value of attribute queued_at.



33
34
35
# File 'lib/zyphr/models/email_message.rb', line 33

def queued_at
  @queued_at
end

#sent_atObject

Returns the value of attribute sent_at.



35
36
37
# File 'lib/zyphr/models/email_message.rb', line 35

def sent_at
  @sent_at
end

#statusObject

Returns the value of attribute status.



26
27
28
# File 'lib/zyphr/models/email_message.rb', line 26

def status
  @status
end

#status_reasonObject

Why the message is in its current status, when applicable. For a suppressed row this is the suppression reason (e.g. recipient_not_allowlisted when blocked by the auth application's test_recipients allowlist). Null for normal sends.



29
30
31
# File 'lib/zyphr/models/email_message.rb', line 29

def status_reason
  @status_reason
end

#subjectObject

Returns the value of attribute subject.



24
25
26
# File 'lib/zyphr/models/email_message.rb', line 24

def subject
  @subject
end

#tagsObject

Returns the value of attribute tags.



31
32
33
# File 'lib/zyphr/models/email_message.rb', line 31

def tags
  @tags
end

#toObject

Returns the value of attribute to.



22
23
24
# File 'lib/zyphr/models/email_message.rb', line 22

def to
  @to
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/zyphr/models/email_message.rb', line 293

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Zyphr.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



90
91
92
# File 'lib/zyphr/models/email_message.rb', line 90

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



95
96
97
# File 'lib/zyphr/models/email_message.rb', line 95

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/zyphr/models/email_message.rb', line 70

def self.attribute_map
  {
    :'id' => :'id',
    :'from' => :'from',
    :'to' => :'to',
    :'subject' => :'subject',
    :'status' => :'status',
    :'status_reason' => :'status_reason',
    :'tags' => :'tags',
    :'queued_at' => :'queued_at',
    :'sent_at' => :'sent_at',
    :'delivered_at' => :'delivered_at',
    :'bounced_at' => :'bounced_at',
    :'opened_at' => :'opened_at',
    :'clicked_at' => :'clicked_at',
    :'created_at' => :'created_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/zyphr/models/email_message.rb', line 269

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
124
125
126
127
128
129
# File 'lib/zyphr/models/email_message.rb', line 120

def self.openapi_nullable
  Set.new([
    :'status_reason',
    :'sent_at',
    :'delivered_at',
    :'bounced_at',
    :'opened_at',
    :'clicked_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/zyphr/models/email_message.rb', line 100

def self.openapi_types
  {
    :'id' => :'String',
    :'from' => :'EmailAddress',
    :'to' => :'EmailAddress',
    :'subject' => :'String',
    :'status' => :'String',
    :'status_reason' => :'String',
    :'tags' => :'Array<String>',
    :'queued_at' => :'Time',
    :'sent_at' => :'Time',
    :'delivered_at' => :'Time',
    :'bounced_at' => :'Time',
    :'opened_at' => :'Time',
    :'clicked_at' => :'Time',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/zyphr/models/email_message.rb', line 235

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      from == o.from &&
      to == o.to &&
      subject == o.subject &&
      status == o.status &&
      status_reason == o.status_reason &&
      tags == o.tags &&
      queued_at == o.queued_at &&
      sent_at == o.sent_at &&
      delivered_at == o.delivered_at &&
      bounced_at == o.bounced_at &&
      opened_at == o.opened_at &&
      clicked_at == o.clicked_at &&
      created_at == o.created_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/zyphr/models/email_message.rb', line 364

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


256
257
258
# File 'lib/zyphr/models/email_message.rb', line 256

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



262
263
264
# File 'lib/zyphr/models/email_message.rb', line 262

def hash
  [id, from, to, subject, status, status_reason, tags, queued_at, sent_at, delivered_at, bounced_at, opened_at, clicked_at, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



208
209
210
211
212
# File 'lib/zyphr/models/email_message.rb', line 208

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



340
341
342
# File 'lib/zyphr/models/email_message.rb', line 340

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/zyphr/models/email_message.rb', line 346

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



334
335
336
# File 'lib/zyphr/models/email_message.rb', line 334

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



216
217
218
219
220
221
# File 'lib/zyphr/models/email_message.rb', line 216

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["pending", "queued", "sent", "delivered", "failed", "bounced", "rejected", "suppressed"])
  return false unless status_validator.valid?(@status)
  true
end