Class: Zyphr::EmailsApi
- Inherits:
-
Object
- Object
- Zyphr::EmailsApi
- Defined in:
- lib/zyphr/api/emails_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_email(id, opts = {}) ⇒ EmailResponse
Get email details Retrieve details for a specific email message.
-
#get_email_events(id, opts = {}) ⇒ EmailEventsResponse
Get email events Retrieve delivery events for a specific email.
-
#get_email_events_with_http_info(id, opts = {}) ⇒ Array<(EmailEventsResponse, Integer, Hash)>
Get email events Retrieve delivery events for a specific email.
-
#get_email_tracking(id, opts = {}) ⇒ EmailTrackingResponse
Get email tracking stats Retrieve open and click tracking statistics.
-
#get_email_tracking_with_http_info(id, opts = {}) ⇒ Array<(EmailTrackingResponse, Integer, Hash)>
Get email tracking stats Retrieve open and click tracking statistics.
-
#get_email_with_http_info(id, opts = {}) ⇒ Array<(EmailResponse, Integer, Hash)>
Get email details Retrieve details for a specific email message.
-
#initialize(api_client = ApiClient.default) ⇒ EmailsApi
constructor
A new instance of EmailsApi.
-
#list_emails(opts = {}) ⇒ EmailListResponse
List emails Retrieve a paginated list of sent emails.
-
#list_emails_with_http_info(opts = {}) ⇒ Array<(EmailListResponse, Integer, Hash)>
List emails Retrieve a paginated list of sent emails.
-
#send_batch_email(send_batch_email_request, opts = {}) ⇒ SendBatchEmailResponse
Send batch emails Send up to 100 emails in a single request.
-
#send_batch_email_with_http_info(send_batch_email_request, opts = {}) ⇒ Array<(SendBatchEmailResponse, Integer, Hash)>
Send batch emails Send up to 100 emails in a single request.
-
#send_email(send_email_request, opts = {}) ⇒ SendEmailResponse
Send an email Queue an email for delivery.
-
#send_email_with_http_info(send_email_request, opts = {}) ⇒ Array<(SendEmailResponse, Integer, Hash)>
Send an email Queue an email for delivery.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zyphr/api/emails_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_email(id, opts = {}) ⇒ EmailResponse
Get email details Retrieve details for a specific email message
27 28 29 30 |
# File 'lib/zyphr/api/emails_api.rb', line 27 def get_email(id, opts = {}) data, _status_code, _headers = get_email_with_http_info(id, opts) data end |
#get_email_events(id, opts = {}) ⇒ EmailEventsResponse
Get email events Retrieve delivery events for a specific email
90 91 92 93 |
# File 'lib/zyphr/api/emails_api.rb', line 90 def get_email_events(id, opts = {}) data, _status_code, _headers = get_email_events_with_http_info(id, opts) data end |
#get_email_events_with_http_info(id, opts = {}) ⇒ Array<(EmailEventsResponse, Integer, Hash)>
Get email events Retrieve delivery events for a specific email
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/zyphr/api/emails_api.rb', line 100 def get_email_events_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EmailsApi.get_email_events ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EmailsApi.get_email_events" end # resource path local_var_path = '/emails/{id}/events'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EmailEventsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EmailsApi.get_email_events", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailsApi#get_email_events\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_email_tracking(id, opts = {}) ⇒ EmailTrackingResponse
Get email tracking stats Retrieve open and click tracking statistics
153 154 155 156 |
# File 'lib/zyphr/api/emails_api.rb', line 153 def get_email_tracking(id, opts = {}) data, _status_code, _headers = get_email_tracking_with_http_info(id, opts) data end |
#get_email_tracking_with_http_info(id, opts = {}) ⇒ Array<(EmailTrackingResponse, Integer, Hash)>
Get email tracking stats Retrieve open and click tracking statistics
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/zyphr/api/emails_api.rb', line 163 def get_email_tracking_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EmailsApi.get_email_tracking ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EmailsApi.get_email_tracking" end # resource path local_var_path = '/emails/{id}/tracking'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EmailTrackingResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EmailsApi.get_email_tracking", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailsApi#get_email_tracking\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_email_with_http_info(id, opts = {}) ⇒ Array<(EmailResponse, Integer, Hash)>
Get email details Retrieve details for a specific email message
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/zyphr/api/emails_api.rb', line 37 def get_email_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EmailsApi.get_email ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EmailsApi.get_email" end # resource path local_var_path = '/emails/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EmailResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EmailsApi.get_email", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailsApi#get_email\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_emails(opts = {}) ⇒ EmailListResponse
List emails Retrieve a paginated list of sent emails
219 220 221 222 |
# File 'lib/zyphr/api/emails_api.rb', line 219 def list_emails(opts = {}) data, _status_code, _headers = list_emails_with_http_info(opts) data end |
#list_emails_with_http_info(opts = {}) ⇒ Array<(EmailListResponse, Integer, Hash)>
List emails Retrieve a paginated list of sent emails
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/zyphr/api/emails_api.rb', line 232 def list_emails_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EmailsApi.list_emails ...' end allowable_values = ["pending", "queued", "sent", "delivered", "failed", "bounced", "rejected"] if @api_client.config.client_side_validation && opts[:'status'] && !allowable_values.include?(opts[:'status']) fail ArgumentError, "invalid value for \"status\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling EmailsApi.list_emails, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling EmailsApi.list_emails, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling EmailsApi.list_emails, must be greater than or equal to 0.' end # resource path local_var_path = '/emails' # query parameters query_params = opts[:query_params] || {} query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? query_params[:'tag'] = opts[:'tag'] if !opts[:'tag'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EmailListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EmailsApi.list_emails", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailsApi#list_emails\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#send_batch_email(send_batch_email_request, opts = {}) ⇒ SendBatchEmailResponse
Send batch emails Send up to 100 emails in a single request. Each recipient gets their own message record.
301 302 303 304 |
# File 'lib/zyphr/api/emails_api.rb', line 301 def send_batch_email(send_batch_email_request, opts = {}) data, _status_code, _headers = send_batch_email_with_http_info(send_batch_email_request, opts) data end |
#send_batch_email_with_http_info(send_batch_email_request, opts = {}) ⇒ Array<(SendBatchEmailResponse, Integer, Hash)>
Send batch emails Send up to 100 emails in a single request. Each recipient gets their own message record.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/zyphr/api/emails_api.rb', line 311 def send_batch_email_with_http_info(send_batch_email_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EmailsApi.send_batch_email ...' end # verify the required parameter 'send_batch_email_request' is set if @api_client.config.client_side_validation && send_batch_email_request.nil? fail ArgumentError, "Missing the required parameter 'send_batch_email_request' when calling EmailsApi.send_batch_email" end # resource path local_var_path = '/emails/batch' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(send_batch_email_request) # return_type return_type = opts[:debug_return_type] || 'SendBatchEmailResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EmailsApi.send_batch_email", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailsApi#send_batch_email\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#send_email(send_email_request, opts = {}) ⇒ SendEmailResponse
Send an email Queue an email for delivery. The email is processed asynchronously and you’ll receive a message ID to track its status. You can provide content directly via ‘html`/`text` fields, or use a template by specifying `template_id` and `template_data`.
369 370 371 372 |
# File 'lib/zyphr/api/emails_api.rb', line 369 def send_email(send_email_request, opts = {}) data, _status_code, _headers = send_email_with_http_info(send_email_request, opts) data end |
#send_email_with_http_info(send_email_request, opts = {}) ⇒ Array<(SendEmailResponse, Integer, Hash)>
Send an email Queue an email for delivery. The email is processed asynchronously and you'll receive a message ID to track its status. You can provide content directly via `html`/`text` fields, or use a template by specifying `template_id` and `template_data`.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/zyphr/api/emails_api.rb', line 379 def send_email_with_http_info(send_email_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EmailsApi.send_email ...' end # verify the required parameter 'send_email_request' is set if @api_client.config.client_side_validation && send_email_request.nil? fail ArgumentError, "Missing the required parameter 'send_email_request' when calling EmailsApi.send_email" end # resource path local_var_path = '/emails' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(send_email_request) # return_type return_type = opts[:debug_return_type] || 'SendEmailResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EmailsApi.send_email", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailsApi#send_email\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |