Class: Zyphr::ExecutionsApi
- Inherits:
-
Object
- Object
- Zyphr::ExecutionsApi
- Defined in:
- lib/zyphr/api/executions_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#cancel_execution(id, opts = {}) ⇒ ExecutionCancelResponse
Cancel a running execution Cancel a workflow execution that is still pending or running.
-
#cancel_execution_with_http_info(id, opts = {}) ⇒ Array<(ExecutionCancelResponse, Integer, Hash)>
Cancel a running execution Cancel a workflow execution that is still pending or running.
-
#get_execution(id, opts = {}) ⇒ ExecutionResponse
Get a workflow execution Retrieve a workflow execution by ID, including its step execution details.
-
#get_execution_with_http_info(id, opts = {}) ⇒ Array<(ExecutionResponse, Integer, Hash)>
Get a workflow execution Retrieve a workflow execution by ID, including its step execution details.
-
#initialize(api_client = ApiClient.default) ⇒ ExecutionsApi
constructor
A new instance of ExecutionsApi.
-
#retry_execution(id, opts = {}) ⇒ ExecutionRetryResponse
Retry a failed or cancelled execution Create a new workflow execution that re-runs the same workflow with the original subscriber, payload, and sender.
-
#retry_execution_with_http_info(id, opts = {}) ⇒ Array<(ExecutionRetryResponse, Integer, Hash)>
Retry a failed or cancelled execution Create a new workflow execution that re-runs the same workflow with the original subscriber, payload, and sender.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ExecutionsApi
Returns a new instance of ExecutionsApi.
19 20 21 |
# File 'lib/zyphr/api/executions_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zyphr/api/executions_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#cancel_execution(id, opts = {}) ⇒ ExecutionCancelResponse
Cancel a running execution Cancel a workflow execution that is still pending or running. Already-terminal executions cannot be cancelled.
27 28 29 30 |
# File 'lib/zyphr/api/executions_api.rb', line 27 def cancel_execution(id, opts = {}) data, _status_code, _headers = cancel_execution_with_http_info(id, opts) data end |
#cancel_execution_with_http_info(id, opts = {}) ⇒ Array<(ExecutionCancelResponse, Integer, Hash)>
Cancel a running execution Cancel a workflow execution that is still pending or running. Already-terminal executions cannot be cancelled.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/zyphr/api/executions_api.rb', line 37 def cancel_execution_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ExecutionsApi.cancel_execution ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ExecutionsApi.cancel_execution" end # resource path local_var_path = '/executions/{id}/cancel'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ExecutionCancelResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ExecutionsApi.cancel_execution", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ExecutionsApi#cancel_execution\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_execution(id, opts = {}) ⇒ ExecutionResponse
Get a workflow execution Retrieve a workflow execution by ID, including its step execution details.
90 91 92 93 |
# File 'lib/zyphr/api/executions_api.rb', line 90 def get_execution(id, opts = {}) data, _status_code, _headers = get_execution_with_http_info(id, opts) data end |
#get_execution_with_http_info(id, opts = {}) ⇒ Array<(ExecutionResponse, Integer, Hash)>
Get a workflow execution Retrieve a workflow execution by ID, including its step execution details.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/zyphr/api/executions_api.rb', line 100 def get_execution_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ExecutionsApi.get_execution ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ExecutionsApi.get_execution" end # resource path local_var_path = '/executions/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ExecutionResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ExecutionsApi.get_execution", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ExecutionsApi#get_execution\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#retry_execution(id, opts = {}) ⇒ ExecutionRetryResponse
Retry a failed or cancelled execution Create a new workflow execution that re-runs the same workflow with the original subscriber, payload, and sender. Only ‘failed` or `cancelled` executions can be retried.
153 154 155 156 |
# File 'lib/zyphr/api/executions_api.rb', line 153 def retry_execution(id, opts = {}) data, _status_code, _headers = retry_execution_with_http_info(id, opts) data end |
#retry_execution_with_http_info(id, opts = {}) ⇒ Array<(ExecutionRetryResponse, Integer, Hash)>
Retry a failed or cancelled execution Create a new workflow execution that re-runs the same workflow with the original subscriber, payload, and sender. Only `failed` or `cancelled` executions can be retried.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/zyphr/api/executions_api.rb', line 163 def retry_execution_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ExecutionsApi.retry_execution ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ExecutionsApi.retry_execution" end # resource path local_var_path = '/executions/{id}/retry'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ExecutionRetryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ExecutionsApi.retry_execution", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ExecutionsApi#retry_execution\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |