Class: Zyphr::InboundEmail

Inherits:
Object
  • Object
show all
Defined in:
lib/zyphr/models/inbound_email.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InboundEmail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/zyphr/models/inbound_email.rb', line 146

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zyphr::InboundEmail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zyphr::InboundEmail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'to_email')
    self.to_email = attributes[:'to_email']
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'cc')
    if (value = attributes[:'cc']).is_a?(Array)
      self.cc = value
    end
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  end

  if attributes.key?(:'text_body')
    self.text_body = attributes[:'text_body']
  end

  if attributes.key?(:'html_body')
    self.html_body = attributes[:'html_body']
  end

  if attributes.key?(:'in_reply_to')
    self.in_reply_to = attributes[:'in_reply_to']
  end

  if attributes.key?(:'replied_to_message_id')
    self.replied_to_message_id = attributes[:'replied_to_message_id']
  end

  if attributes.key?(:'verified')
    self.verified = attributes[:'verified']
  end

  if attributes.key?(:'spf_verdict')
    self.spf_verdict = attributes[:'spf_verdict']
  end

  if attributes.key?(:'dkim_verdict')
    self.dkim_verdict = attributes[:'dkim_verdict']
  end

  if attributes.key?(:'dmarc_verdict')
    self.dmarc_verdict = attributes[:'dmarc_verdict']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#attachmentsObject

Returns the value of attribute attachments.



50
51
52
# File 'lib/zyphr/models/inbound_email.rb', line 50

def attachments
  @attachments
end

#ccObject

Returns the value of attribute cc.



25
26
27
# File 'lib/zyphr/models/inbound_email.rb', line 25

def cc
  @cc
end

#created_atObject

Returns the value of attribute created_at.



52
53
54
# File 'lib/zyphr/models/inbound_email.rb', line 52

def created_at
  @created_at
end

#dkim_verdictObject

Returns the value of attribute dkim_verdict.



44
45
46
# File 'lib/zyphr/models/inbound_email.rb', line 44

def dkim_verdict
  @dkim_verdict
end

#dmarc_verdictObject

Returns the value of attribute dmarc_verdict.



46
47
48
# File 'lib/zyphr/models/inbound_email.rb', line 46

def dmarc_verdict
  @dmarc_verdict
end

#fromObject

Returns the value of attribute from.



23
24
25
# File 'lib/zyphr/models/inbound_email.rb', line 23

def from
  @from
end

#html_bodyObject

Returns the value of attribute html_body.



31
32
33
# File 'lib/zyphr/models/inbound_email.rb', line 31

def html_body
  @html_body
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zyphr/models/inbound_email.rb', line 18

def id
  @id
end

#in_reply_toObject

RFC Message-ID this is a reply to, if any



34
35
36
# File 'lib/zyphr/models/inbound_email.rb', line 34

def in_reply_to
  @in_reply_to
end

#replied_to_message_idObject

Resolved outbound message this is a reply to, if correlated



37
38
39
# File 'lib/zyphr/models/inbound_email.rb', line 37

def replied_to_message_id
  @replied_to_message_id
end

#spf_verdictObject

Returns the value of attribute spf_verdict.



42
43
44
# File 'lib/zyphr/models/inbound_email.rb', line 42

def spf_verdict
  @spf_verdict
end

#statusObject

Returns the value of attribute status.



48
49
50
# File 'lib/zyphr/models/inbound_email.rb', line 48

def status
  @status
end

#subjectObject

Returns the value of attribute subject.



27
28
29
# File 'lib/zyphr/models/inbound_email.rb', line 27

def subject
  @subject
end

#text_bodyObject

Returns the value of attribute text_body.



29
30
31
# File 'lib/zyphr/models/inbound_email.rb', line 29

def text_body
  @text_body
end

#to_emailObject

The receiving address the mail was sent to



21
22
23
# File 'lib/zyphr/models/inbound_email.rb', line 21

def to_email
  @to_email
end

#verifiedObject

False when SPF or DMARC failed — treat the sender as unverified



40
41
42
# File 'lib/zyphr/models/inbound_email.rb', line 40

def verified
  @verified
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/zyphr/models/inbound_email.rb', line 354

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Zyphr.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



99
100
101
# File 'lib/zyphr/models/inbound_email.rb', line 99

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



104
105
106
# File 'lib/zyphr/models/inbound_email.rb', line 104

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/zyphr/models/inbound_email.rb', line 77

def self.attribute_map
  {
    :'id' => :'id',
    :'to_email' => :'to_email',
    :'from' => :'from',
    :'cc' => :'cc',
    :'subject' => :'subject',
    :'text_body' => :'text_body',
    :'html_body' => :'html_body',
    :'in_reply_to' => :'in_reply_to',
    :'replied_to_message_id' => :'replied_to_message_id',
    :'verified' => :'verified',
    :'spf_verdict' => :'spf_verdict',
    :'dkim_verdict' => :'dkim_verdict',
    :'dmarc_verdict' => :'dmarc_verdict',
    :'status' => :'status',
    :'attachments' => :'attachments',
    :'created_at' => :'created_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/zyphr/models/inbound_email.rb', line 330

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/zyphr/models/inbound_email.rb', line 131

def self.openapi_nullable
  Set.new([
    :'subject',
    :'text_body',
    :'html_body',
    :'in_reply_to',
    :'replied_to_message_id',
    :'spf_verdict',
    :'dkim_verdict',
    :'dmarc_verdict',
  ])
end

.openapi_typesObject

Attribute type mapping.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/zyphr/models/inbound_email.rb', line 109

def self.openapi_types
  {
    :'id' => :'String',
    :'to_email' => :'String',
    :'from' => :'InboundEmailFrom',
    :'cc' => :'Array<String>',
    :'subject' => :'String',
    :'text_body' => :'String',
    :'html_body' => :'String',
    :'in_reply_to' => :'String',
    :'replied_to_message_id' => :'String',
    :'verified' => :'Boolean',
    :'spf_verdict' => :'String',
    :'dkim_verdict' => :'String',
    :'dmarc_verdict' => :'String',
    :'status' => :'String',
    :'attachments' => :'Array<InboundEmailAttachment>',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/zyphr/models/inbound_email.rb', line 294

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      to_email == o.to_email &&
      from == o.from &&
      cc == o.cc &&
      subject == o.subject &&
      text_body == o.text_body &&
      html_body == o.html_body &&
      in_reply_to == o.in_reply_to &&
      replied_to_message_id == o.replied_to_message_id &&
      verified == o.verified &&
      spf_verdict == o.spf_verdict &&
      dkim_verdict == o.dkim_verdict &&
      dmarc_verdict == o.dmarc_verdict &&
      status == o.status &&
      attachments == o.attachments &&
      created_at == o.created_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/zyphr/models/inbound_email.rb', line 425

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


317
318
319
# File 'lib/zyphr/models/inbound_email.rb', line 317

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



323
324
325
# File 'lib/zyphr/models/inbound_email.rb', line 323

def hash
  [id, to_email, from, cc, subject, text_body, html_body, in_reply_to, replied_to_message_id, verified, spf_verdict, dkim_verdict, dmarc_verdict, status, attachments, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



231
232
233
234
235
# File 'lib/zyphr/models/inbound_email.rb', line 231

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



401
402
403
# File 'lib/zyphr/models/inbound_email.rb', line 401

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/zyphr/models/inbound_email.rb', line 407

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



395
396
397
# File 'lib/zyphr/models/inbound_email.rb', line 395

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/zyphr/models/inbound_email.rb', line 239

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  spf_verdict_validator = EnumAttributeValidator.new('String', ["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"])
  return false unless spf_verdict_validator.valid?(@spf_verdict)
  dkim_verdict_validator = EnumAttributeValidator.new('String', ["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"])
  return false unless dkim_verdict_validator.valid?(@dkim_verdict)
  dmarc_verdict_validator = EnumAttributeValidator.new('String', ["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"])
  return false unless dmarc_verdict_validator.valid?(@dmarc_verdict)
  status_validator = EnumAttributeValidator.new('String', ["received", "processed", "quarantined", "dropped", "failed"])
  return false unless status_validator.valid?(@status)
  true
end