Class: Zyphr::PushEvent
- Inherits:
-
Object
- Object
- Zyphr::PushEvent
- Defined in:
- lib/zyphr/models/push_event.rb
Instance Attribute Summary collapse
-
#error_code ⇒ Object
Returns the value of attribute error_code.
-
#error_message ⇒ Object
Returns the value of attribute error_message.
-
#event_timestamp ⇒ Object
Returns the value of attribute event_timestamp.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#id ⇒ Object
Returns the value of attribute id.
-
#provider ⇒ Object
Returns the value of attribute provider.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PushEvent
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PushEvent
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/zyphr/models/push_event.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zyphr::PushEvent` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zyphr::PushEvent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'event_type') self.event_type = attributes[:'event_type'] end if attributes.key?(:'provider') self.provider = attributes[:'provider'] end if attributes.key?(:'error_code') self.error_code = attributes[:'error_code'] end if attributes.key?(:'error_message') self. = attributes[:'error_message'] end if attributes.key?(:'event_timestamp') self. = attributes[:'event_timestamp'] end end |
Instance Attribute Details
#error_code ⇒ Object
Returns the value of attribute error_code.
24 25 26 |
# File 'lib/zyphr/models/push_event.rb', line 24 def error_code @error_code end |
#error_message ⇒ Object
Returns the value of attribute error_message.
26 27 28 |
# File 'lib/zyphr/models/push_event.rb', line 26 def @error_message end |
#event_timestamp ⇒ Object
Returns the value of attribute event_timestamp.
28 29 30 |
# File 'lib/zyphr/models/push_event.rb', line 28 def @event_timestamp end |
#event_type ⇒ Object
Returns the value of attribute event_type.
20 21 22 |
# File 'lib/zyphr/models/push_event.rb', line 20 def event_type @event_type end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zyphr/models/push_event.rb', line 18 def id @id end |
#provider ⇒ Object
Returns the value of attribute provider.
22 23 24 |
# File 'lib/zyphr/models/push_event.rb', line 22 def provider @provider end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/zyphr/models/push_event.rb', line 180 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Zyphr.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/zyphr/models/push_event.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/zyphr/models/push_event.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/zyphr/models/push_event.rb', line 31 def self.attribute_map { :'id' => :'id', :'event_type' => :'event_type', :'provider' => :'provider', :'error_code' => :'error_code', :'error_message' => :'error_message', :'event_timestamp' => :'event_timestamp' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/zyphr/models/push_event.rb', line 156 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 69 70 |
# File 'lib/zyphr/models/push_event.rb', line 65 def self.openapi_nullable Set.new([ :'error_code', :'error_message', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/zyphr/models/push_event.rb', line 53 def self.openapi_types { :'id' => :'String', :'event_type' => :'String', :'provider' => :'String', :'error_code' => :'String', :'error_message' => :'String', :'event_timestamp' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 137 138 139 |
# File 'lib/zyphr/models/push_event.rb', line 130 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && event_type == o.event_type && provider == o.provider && error_code == o.error_code && == o. && == o. end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/zyphr/models/push_event.rb', line 251 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
143 144 145 |
# File 'lib/zyphr/models/push_event.rb', line 143 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
149 150 151 |
# File 'lib/zyphr/models/push_event.rb', line 149 def hash [id, event_type, provider, error_code, , ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
115 116 117 118 119 |
# File 'lib/zyphr/models/push_event.rb', line 115 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
227 228 229 |
# File 'lib/zyphr/models/push_event.rb', line 227 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/zyphr/models/push_event.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
221 222 223 |
# File 'lib/zyphr/models/push_event.rb', line 221 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
123 124 125 126 |
# File 'lib/zyphr/models/push_event.rb', line 123 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |