Class: Zyphr::PushMessageDetail

Inherits:
Object
  • Object
show all
Defined in:
lib/zyphr/models/push_message_detail.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PushMessageDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/zyphr/models/push_message_detail.rb', line 184

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zyphr::PushMessageDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zyphr::PushMessageDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'device_id')
    self.device_id = attributes[:'device_id']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'data')
    if (value = attributes[:'data']).is_a?(Hash)
      self.data = value
    end
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'queued_at')
    self.queued_at = attributes[:'queued_at']
  end

  if attributes.key?(:'sent_at')
    self.sent_at = attributes[:'sent_at']
  end

  if attributes.key?(:'delivered_at')
    self.delivered_at = attributes[:'delivered_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'batch_id')
    self.batch_id = attributes[:'batch_id']
  end

  if attributes.key?(:'badge')
    self.badge = attributes[:'badge']
  end

  if attributes.key?(:'sound')
    self.sound = attributes[:'sound']
  end

  if attributes.key?(:'image_url')
    self.image_url = attributes[:'image_url']
  end

  if attributes.key?(:'content_available')
    self.content_available = attributes[:'content_available']
  end

  if attributes.key?(:'action_buttons')
    if (value = attributes[:'action_buttons']).is_a?(Array)
      self.action_buttons = value
    end
  end

  if attributes.key?(:'status_reason')
    self.status_reason = attributes[:'status_reason']
  end

  if attributes.key?(:'provider_message_id')
    self.provider_message_id = attributes[:'provider_message_id']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'failed_at')
    self.failed_at = attributes[:'failed_at']
  end

  if attributes.key?(:'events')
    if (value = attributes[:'events']).is_a?(Array)
      self.events = value
    end
  end
end

Instance Attribute Details

#action_buttonsObject

Returns the value of attribute action_buttons.



54
55
56
# File 'lib/zyphr/models/push_message_detail.rb', line 54

def action_buttons
  @action_buttons
end

#badgeObject

Returns the value of attribute badge.



46
47
48
# File 'lib/zyphr/models/push_message_detail.rb', line 46

def badge
  @badge
end

#batch_idObject

Returns the value of attribute batch_id.



44
45
46
# File 'lib/zyphr/models/push_message_detail.rb', line 44

def batch_id
  @batch_id
end

#bodyObject

Returns the value of attribute body.



28
29
30
# File 'lib/zyphr/models/push_message_detail.rb', line 28

def body
  @body
end

#content_availableObject

Returns the value of attribute content_available.



52
53
54
# File 'lib/zyphr/models/push_message_detail.rb', line 52

def content_available
  @content_available
end

#created_atObject

Returns the value of attribute created_at.



42
43
44
# File 'lib/zyphr/models/push_message_detail.rb', line 42

def created_at
  @created_at
end

#dataObject

Returns the value of attribute data.



30
31
32
# File 'lib/zyphr/models/push_message_detail.rb', line 30

def data
  @data
end

#delivered_atObject

Returns the value of attribute delivered_at.



40
41
42
# File 'lib/zyphr/models/push_message_detail.rb', line 40

def delivered_at
  @delivered_at
end

#device_idObject

Returns the value of attribute device_id.



20
21
22
# File 'lib/zyphr/models/push_message_detail.rb', line 20

def device_id
  @device_id
end

#eventsObject

Returns the value of attribute events.



64
65
66
# File 'lib/zyphr/models/push_message_detail.rb', line 64

def events
  @events
end

#failed_atObject

Returns the value of attribute failed_at.



62
63
64
# File 'lib/zyphr/models/push_message_detail.rb', line 62

def failed_at
  @failed_at
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zyphr/models/push_message_detail.rb', line 18

def id
  @id
end

#image_urlObject

Returns the value of attribute image_url.



50
51
52
# File 'lib/zyphr/models/push_message_detail.rb', line 50

def image_url
  @image_url
end

#metadataObject

Returns the value of attribute metadata.



60
61
62
# File 'lib/zyphr/models/push_message_detail.rb', line 60

def 
  @metadata
end

#platformObject

Returns the value of attribute platform.



24
25
26
# File 'lib/zyphr/models/push_message_detail.rb', line 24

def platform
  @platform
end

#provider_message_idObject

Returns the value of attribute provider_message_id.



58
59
60
# File 'lib/zyphr/models/push_message_detail.rb', line 58

def provider_message_id
  @provider_message_id
end

#queued_atObject

Returns the value of attribute queued_at.



36
37
38
# File 'lib/zyphr/models/push_message_detail.rb', line 36

def queued_at
  @queued_at
end

#sent_atObject

Returns the value of attribute sent_at.



38
39
40
# File 'lib/zyphr/models/push_message_detail.rb', line 38

def sent_at
  @sent_at
end

#soundObject

Returns the value of attribute sound.



48
49
50
# File 'lib/zyphr/models/push_message_detail.rb', line 48

def sound
  @sound
end

#statusObject

Returns the value of attribute status.



32
33
34
# File 'lib/zyphr/models/push_message_detail.rb', line 32

def status
  @status
end

#status_reasonObject

Returns the value of attribute status_reason.



56
57
58
# File 'lib/zyphr/models/push_message_detail.rb', line 56

def status_reason
  @status_reason
end

#tagsObject

Returns the value of attribute tags.



34
35
36
# File 'lib/zyphr/models/push_message_detail.rb', line 34

def tags
  @tags
end

#titleObject

Returns the value of attribute title.



26
27
28
# File 'lib/zyphr/models/push_message_detail.rb', line 26

def title
  @title
end

#user_idObject

Returns the value of attribute user_id.



22
23
24
# File 'lib/zyphr/models/push_message_detail.rb', line 22

def user_id
  @user_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
# File 'lib/zyphr/models/push_message_detail.rb', line 414

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Zyphr.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



119
120
121
# File 'lib/zyphr/models/push_message_detail.rb', line 119

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



124
125
126
# File 'lib/zyphr/models/push_message_detail.rb', line 124

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/zyphr/models/push_message_detail.rb', line 89

def self.attribute_map
  {
    :'id' => :'id',
    :'device_id' => :'device_id',
    :'user_id' => :'user_id',
    :'platform' => :'platform',
    :'title' => :'title',
    :'body' => :'body',
    :'data' => :'data',
    :'status' => :'status',
    :'tags' => :'tags',
    :'queued_at' => :'queued_at',
    :'sent_at' => :'sent_at',
    :'delivered_at' => :'delivered_at',
    :'created_at' => :'created_at',
    :'batch_id' => :'batch_id',
    :'badge' => :'badge',
    :'sound' => :'sound',
    :'image_url' => :'image_url',
    :'content_available' => :'content_available',
    :'action_buttons' => :'action_buttons',
    :'status_reason' => :'status_reason',
    :'provider_message_id' => :'provider_message_id',
    :'metadata' => :'metadata',
    :'failed_at' => :'failed_at',
    :'events' => :'events'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/zyphr/models/push_message_detail.rb', line 390

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



176
177
178
179
180
# File 'lib/zyphr/models/push_message_detail.rb', line 176

def self.openapi_all_of
  [
  :'PushMessage'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/zyphr/models/push_message_detail.rb', line 159

def self.openapi_nullable
  Set.new([
    :'queued_at',
    :'sent_at',
    :'delivered_at',
    :'batch_id',
    :'badge',
    :'sound',
    :'image_url',
    :'action_buttons',
    :'status_reason',
    :'provider_message_id',
    :'failed_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/zyphr/models/push_message_detail.rb', line 129

def self.openapi_types
  {
    :'id' => :'String',
    :'device_id' => :'String',
    :'user_id' => :'String',
    :'platform' => :'String',
    :'title' => :'String',
    :'body' => :'String',
    :'data' => :'Hash<String, Object>',
    :'status' => :'String',
    :'tags' => :'Array<String>',
    :'queued_at' => :'Time',
    :'sent_at' => :'Time',
    :'delivered_at' => :'Time',
    :'created_at' => :'Time',
    :'batch_id' => :'String',
    :'badge' => :'Integer',
    :'sound' => :'String',
    :'image_url' => :'String',
    :'content_available' => :'Boolean',
    :'action_buttons' => :'Array<PushMessageDetailAllOfActionButtons>',
    :'status_reason' => :'String',
    :'provider_message_id' => :'String',
    :'metadata' => :'Hash<String, Object>',
    :'failed_at' => :'Time',
    :'events' => :'Array<PushEvent>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/zyphr/models/push_message_detail.rb', line 346

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      device_id == o.device_id &&
      user_id == o.user_id &&
      platform == o.platform &&
      title == o.title &&
      body == o.body &&
      data == o.data &&
      status == o.status &&
      tags == o.tags &&
      queued_at == o.queued_at &&
      sent_at == o.sent_at &&
      delivered_at == o.delivered_at &&
      created_at == o.created_at &&
      batch_id == o.batch_id &&
      badge == o.badge &&
      sound == o.sound &&
      image_url == o.image_url &&
      content_available == o.content_available &&
      action_buttons == o.action_buttons &&
      status_reason == o.status_reason &&
      provider_message_id == o.provider_message_id &&
       == o. &&
      failed_at == o.failed_at &&
      events == o.events
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



485
486
487
488
489
490
491
492
493
494
495
496
497
# File 'lib/zyphr/models/push_message_detail.rb', line 485

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


377
378
379
# File 'lib/zyphr/models/push_message_detail.rb', line 377

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



383
384
385
# File 'lib/zyphr/models/push_message_detail.rb', line 383

def hash
  [id, device_id, user_id, platform, title, body, data, status, tags, queued_at, sent_at, delivered_at, created_at, batch_id, badge, sound, image_url, content_available, action_buttons, status_reason, provider_message_id, , failed_at, events].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



307
308
309
310
311
# File 'lib/zyphr/models/push_message_detail.rb', line 307

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



461
462
463
# File 'lib/zyphr/models/push_message_detail.rb', line 461

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



467
468
469
470
471
472
473
474
475
476
477
478
479
# File 'lib/zyphr/models/push_message_detail.rb', line 467

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



455
456
457
# File 'lib/zyphr/models/push_message_detail.rb', line 455

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



315
316
317
318
319
320
321
322
# File 'lib/zyphr/models/push_message_detail.rb', line 315

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  platform_validator = EnumAttributeValidator.new('String', ["ios", "android", "web"])
  return false unless platform_validator.valid?(@platform)
  status_validator = EnumAttributeValidator.new('String', ["queued", "sending", "sent", "delivered", "failed", "expired"])
  return false unless status_validator.valid?(@status)
  true
end