Class: Zyphr::SendEmailRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/zyphr/models/send_email_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SendEmailRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/zyphr/models/send_email_request.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zyphr::SendEmailRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zyphr::SendEmailRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'to')
    if (value = attributes[:'to']).is_a?(Array)
      self.to = value
    end
  else
    self.to = nil
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'reply_to')
    self.reply_to = attributes[:'reply_to']
  end

  if attributes.key?(:'cc')
    if (value = attributes[:'cc']).is_a?(Array)
      self.cc = value
    end
  end

  if attributes.key?(:'bcc')
    if (value = attributes[:'bcc']).is_a?(Array)
      self.bcc = value
    end
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  else
    self.subject = nil
  end

  if attributes.key?(:'html')
    self.html = attributes[:'html']
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  end

  if attributes.key?(:'template_data')
    if (value = attributes[:'template_data']).is_a?(Hash)
      self.template_data = value
    end
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end

  if attributes.key?(:'headers')
    if (value = attributes[:'headers']).is_a?(Hash)
      self.headers = value
    end
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'scheduled_at')
    self.scheduled_at = attributes[:'scheduled_at']
  end

  if attributes.key?(:'subscriber_id')
    self.subscriber_id = attributes[:'subscriber_id']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end
end

Instance Attribute Details

#attachmentsObject

Returns the value of attribute attachments.



45
46
47
# File 'lib/zyphr/models/send_email_request.rb', line 45

def attachments
  @attachments
end

#bccObject

BCC recipient email address(es).



31
32
33
# File 'lib/zyphr/models/send_email_request.rb', line 31

def bcc
  @bcc
end

#categoryObject

Notification category for preference filtering



60
61
62
# File 'lib/zyphr/models/send_email_request.rb', line 60

def category
  @category
end

#ccObject

CC recipient email address(es).



28
29
30
# File 'lib/zyphr/models/send_email_request.rb', line 28

def cc
  @cc
end

#fromObject

Sender address. The API also accepts a plain email string for convenience.



22
23
24
# File 'lib/zyphr/models/send_email_request.rb', line 22

def from
  @from
end

#headersObject

Returns the value of attribute headers.



47
48
49
# File 'lib/zyphr/models/send_email_request.rb', line 47

def headers
  @headers
end

#htmlObject

Returns the value of attribute html.



35
36
37
# File 'lib/zyphr/models/send_email_request.rb', line 35

def html
  @html
end

#metadataObject

Returns the value of attribute metadata.



51
52
53
# File 'lib/zyphr/models/send_email_request.rb', line 51

def 
  @metadata
end

#reply_toObject

Reply-to address. The API also accepts a plain email string for convenience.



25
26
27
# File 'lib/zyphr/models/send_email_request.rb', line 25

def reply_to
  @reply_to
end

#scheduled_atObject

Schedule email for future delivery



54
55
56
# File 'lib/zyphr/models/send_email_request.rb', line 54

def scheduled_at
  @scheduled_at
end

#subjectObject

Returns the value of attribute subject.



33
34
35
# File 'lib/zyphr/models/send_email_request.rb', line 33

def subject
  @subject
end

#subscriber_idObject

Associate with a subscriber for preference checking



57
58
59
# File 'lib/zyphr/models/send_email_request.rb', line 57

def subscriber_id
  @subscriber_id
end

#tagsObject

Returns the value of attribute tags.



49
50
51
# File 'lib/zyphr/models/send_email_request.rb', line 49

def tags
  @tags
end

#template_dataObject

Variables to pass to the template



43
44
45
# File 'lib/zyphr/models/send_email_request.rb', line 43

def template_data
  @template_data
end

#template_idObject

Template ID to use instead of html/text



40
41
42
# File 'lib/zyphr/models/send_email_request.rb', line 40

def template_id
  @template_id
end

#textObject

Returns the value of attribute text.



37
38
39
# File 'lib/zyphr/models/send_email_request.rb', line 37

def text
  @text
end

#toObject

Recipient(s). An array of EmailAddress objects. The API also accepts a single email string or an array of email strings for convenience.



19
20
21
# File 'lib/zyphr/models/send_email_request.rb', line 19

def to
  @to
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/zyphr/models/send_email_request.rb', line 337

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Zyphr.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/zyphr/models/send_email_request.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/zyphr/models/send_email_request.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/zyphr/models/send_email_request.rb', line 63

def self.attribute_map
  {
    :'to' => :'to',
    :'from' => :'from',
    :'reply_to' => :'reply_to',
    :'cc' => :'cc',
    :'bcc' => :'bcc',
    :'subject' => :'subject',
    :'html' => :'html',
    :'text' => :'text',
    :'template_id' => :'template_id',
    :'template_data' => :'template_data',
    :'attachments' => :'attachments',
    :'headers' => :'headers',
    :'tags' => :'tags',
    :'metadata' => :'metadata',
    :'scheduled_at' => :'scheduled_at',
    :'subscriber_id' => :'subscriber_id',
    :'category' => :'category'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/zyphr/models/send_email_request.rb', line 313

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



119
120
121
122
# File 'lib/zyphr/models/send_email_request.rb', line 119

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/zyphr/models/send_email_request.rb', line 96

def self.openapi_types
  {
    :'to' => :'Array<EmailAddress>',
    :'from' => :'EmailAddress',
    :'reply_to' => :'EmailAddress',
    :'cc' => :'Array<String>',
    :'bcc' => :'Array<String>',
    :'subject' => :'String',
    :'html' => :'String',
    :'text' => :'String',
    :'template_id' => :'String',
    :'template_data' => :'Hash<String, Object>',
    :'attachments' => :'Array<EmailAttachment>',
    :'headers' => :'Hash<String, String>',
    :'tags' => :'Array<String>',
    :'metadata' => :'Hash<String, Object>',
    :'scheduled_at' => :'Time',
    :'subscriber_id' => :'String',
    :'category' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/zyphr/models/send_email_request.rb', line 276

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      to == o.to &&
      from == o.from &&
      reply_to == o.reply_to &&
      cc == o.cc &&
      bcc == o.bcc &&
      subject == o.subject &&
      html == o.html &&
      text == o.text &&
      template_id == o.template_id &&
      template_data == o.template_data &&
      attachments == o.attachments &&
      headers == o.headers &&
      tags == o.tags &&
       == o. &&
      scheduled_at == o.scheduled_at &&
      subscriber_id == o.subscriber_id &&
      category == o.category
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/zyphr/models/send_email_request.rb', line 408

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


300
301
302
# File 'lib/zyphr/models/send_email_request.rb', line 300

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



306
307
308
# File 'lib/zyphr/models/send_email_request.rb', line 306

def hash
  [to, from, reply_to, cc, bcc, subject, html, text, template_id, template_data, attachments, headers, tags, , scheduled_at, subscriber_id, category].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/zyphr/models/send_email_request.rb', line 231

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @to.nil?
    invalid_properties.push('invalid value for "to", to cannot be nil.')
  end

  if @subject.nil?
    invalid_properties.push('invalid value for "subject", subject cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



384
385
386
# File 'lib/zyphr/models/send_email_request.rb', line 384

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/zyphr/models/send_email_request.rb', line 390

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



378
379
380
# File 'lib/zyphr/models/send_email_request.rb', line 378

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



247
248
249
250
251
252
# File 'lib/zyphr/models/send_email_request.rb', line 247

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @to.nil?
  return false if @subject.nil?
  true
end