Class: Zyphr::SendInAppRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/zyphr/models/send_in_app_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SendInAppRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/zyphr/models/send_in_app_request.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zyphr::SendInAppRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zyphr::SendInAppRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'subscriber_id')
    self.subscriber_id = attributes[:'subscriber_id']
  else
    self.subscriber_id = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'action_url')
    self.action_url = attributes[:'action_url']
  end

  if attributes.key?(:'action_label')
    self.action_label = attributes[:'action_label']
  end

  if attributes.key?(:'image_url')
    self.image_url = attributes[:'image_url']
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'priority')
    self.priority = attributes[:'priority']
  else
    self.priority = 'normal'
  end

  if attributes.key?(:'data')
    if (value = attributes[:'data']).is_a?(Hash)
      self.data = value
    end
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end
end

Instance Attribute Details

#action_labelObject

Returns the value of attribute action_label.



26
27
28
# File 'lib/zyphr/models/send_in_app_request.rb', line 26

def action_label
  @action_label
end

#action_urlObject

Returns the value of attribute action_url.



24
25
26
# File 'lib/zyphr/models/send_in_app_request.rb', line 24

def action_url
  @action_url
end

#bodyObject

Returns the value of attribute body.



22
23
24
# File 'lib/zyphr/models/send_in_app_request.rb', line 22

def body
  @body
end

#categoryObject

Returns the value of attribute category.



32
33
34
# File 'lib/zyphr/models/send_in_app_request.rb', line 32

def category
  @category
end

#dataObject

Returns the value of attribute data.



36
37
38
# File 'lib/zyphr/models/send_in_app_request.rb', line 36

def data
  @data
end

#expires_atObject

Returns the value of attribute expires_at.



40
41
42
# File 'lib/zyphr/models/send_in_app_request.rb', line 40

def expires_at
  @expires_at
end

#iconObject

Returns the value of attribute icon.



30
31
32
# File 'lib/zyphr/models/send_in_app_request.rb', line 30

def icon
  @icon
end

#image_urlObject

Returns the value of attribute image_url.



28
29
30
# File 'lib/zyphr/models/send_in_app_request.rb', line 28

def image_url
  @image_url
end

#priorityObject

Returns the value of attribute priority.



34
35
36
# File 'lib/zyphr/models/send_in_app_request.rb', line 34

def priority
  @priority
end

#subscriber_idObject

Returns the value of attribute subscriber_id.



18
19
20
# File 'lib/zyphr/models/send_in_app_request.rb', line 18

def subscriber_id
  @subscriber_id
end

#tagsObject

Returns the value of attribute tags.



38
39
40
# File 'lib/zyphr/models/send_in_app_request.rb', line 38

def tags
  @tags
end

#titleObject

Returns the value of attribute title.



20
21
22
# File 'lib/zyphr/models/send_in_app_request.rb', line 20

def title
  @title
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/zyphr/models/send_in_app_request.rb', line 306

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Zyphr.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



83
84
85
# File 'lib/zyphr/models/send_in_app_request.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/zyphr/models/send_in_app_request.rb', line 88

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/zyphr/models/send_in_app_request.rb', line 65

def self.attribute_map
  {
    :'subscriber_id' => :'subscriber_id',
    :'title' => :'title',
    :'body' => :'body',
    :'action_url' => :'action_url',
    :'action_label' => :'action_label',
    :'image_url' => :'image_url',
    :'icon' => :'icon',
    :'category' => :'category',
    :'priority' => :'priority',
    :'data' => :'data',
    :'tags' => :'tags',
    :'expires_at' => :'expires_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/zyphr/models/send_in_app_request.rb', line 282

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
# File 'lib/zyphr/models/send_in_app_request.rb', line 111

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/zyphr/models/send_in_app_request.rb', line 93

def self.openapi_types
  {
    :'subscriber_id' => :'String',
    :'title' => :'String',
    :'body' => :'String',
    :'action_url' => :'String',
    :'action_label' => :'String',
    :'image_url' => :'String',
    :'icon' => :'String',
    :'category' => :'String',
    :'priority' => :'String',
    :'data' => :'Hash<String, Object>',
    :'tags' => :'Array<String>',
    :'expires_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/zyphr/models/send_in_app_request.rb', line 250

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      subscriber_id == o.subscriber_id &&
      title == o.title &&
      body == o.body &&
      action_url == o.action_url &&
      action_label == o.action_label &&
      image_url == o.image_url &&
      icon == o.icon &&
      category == o.category &&
      priority == o.priority &&
      data == o.data &&
      tags == o.tags &&
      expires_at == o.expires_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/zyphr/models/send_in_app_request.rb', line 377

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


269
270
271
# File 'lib/zyphr/models/send_in_app_request.rb', line 269

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



275
276
277
# File 'lib/zyphr/models/send_in_app_request.rb', line 275

def hash
  [subscriber_id, title, body, action_url, action_label, image_url, icon, category, priority, data, tags, expires_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/zyphr/models/send_in_app_request.rb', line 193

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @subscriber_id.nil?
    invalid_properties.push('invalid value for "subscriber_id", subscriber_id cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



353
354
355
# File 'lib/zyphr/models/send_in_app_request.rb', line 353

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/zyphr/models/send_in_app_request.rb', line 359

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



347
348
349
# File 'lib/zyphr/models/send_in_app_request.rb', line 347

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



209
210
211
212
213
214
215
216
# File 'lib/zyphr/models/send_in_app_request.rb', line 209

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @subscriber_id.nil?
  return false if @title.nil?
  priority_validator = EnumAttributeValidator.new('String', ["low", "normal", "high", "urgent"])
  return false unless priority_validator.valid?(@priority)
  true
end