Class: Zyphr::SendSlackMessageRequest
- Inherits:
-
Object
- Object
- Zyphr::SendSlackMessageRequest
- Defined in:
- lib/zyphr/models/send_slack_message_request.rb
Overview
Either ‘text` or `blocks` must be provided. If `connection_id` is omitted, the project’s default Slack connection is used. If ‘channel` is omitted, the connection’s default channel is used.
Instance Attribute Summary collapse
-
#attachments ⇒ Object
Slack message attachments (legacy formatting).
-
#blocks ⇒ Object
Slack Block Kit blocks for rich formatting.
-
#channel ⇒ Object
Slack channel ID (e.g. ‘C0123456789`).
-
#connection_id ⇒ Object
ID of the Slack connection to send through.
-
#metadata ⇒ Object
Custom metadata to attach to the message.
-
#mrkdwn ⇒ Object
Enable Slack markdown processing.
-
#reply_broadcast ⇒ Object
Also post thread replies to the channel.
-
#tags ⇒ Object
Tags for message categorisation.
-
#text ⇒ Object
Message text.
-
#thread_ts ⇒ Object
Thread timestamp to reply in a thread.
-
#unfurl_links ⇒ Object
Enable link previews.
-
#unfurl_media ⇒ Object
Enable media previews.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SendSlackMessageRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ SendSlackMessageRequest
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zyphr::SendSlackMessageRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zyphr::SendSlackMessageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'connection_id') self.connection_id = attributes[:'connection_id'] end if attributes.key?(:'channel') self.channel = attributes[:'channel'] end if attributes.key?(:'text') self.text = attributes[:'text'] end if attributes.key?(:'blocks') if (value = attributes[:'blocks']).is_a?(Array) self.blocks = value end end if attributes.key?(:'attachments') if (value = attributes[:'attachments']).is_a?(Array) self. = value end end if attributes.key?(:'thread_ts') self.thread_ts = attributes[:'thread_ts'] end if attributes.key?(:'reply_broadcast') self.reply_broadcast = attributes[:'reply_broadcast'] end if attributes.key?(:'unfurl_links') self.unfurl_links = attributes[:'unfurl_links'] end if attributes.key?(:'unfurl_media') self.unfurl_media = attributes[:'unfurl_media'] end if attributes.key?(:'mrkdwn') self.mrkdwn = attributes[:'mrkdwn'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#attachments ⇒ Object
Slack message attachments (legacy formatting).
32 33 34 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 32 def @attachments end |
#blocks ⇒ Object
Slack Block Kit blocks for rich formatting.
29 30 31 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 29 def blocks @blocks end |
#channel ⇒ Object
Slack channel ID (e.g. ‘C0123456789`). Falls back to the connection’s default channel.
23 24 25 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 23 def channel @channel end |
#connection_id ⇒ Object
ID of the Slack connection to send through. Defaults to the project’s active connection.
20 21 22 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 20 def connection_id @connection_id end |
#metadata ⇒ Object
Custom metadata to attach to the message.
50 51 52 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 50 def @metadata end |
#mrkdwn ⇒ Object
Enable Slack markdown processing.
47 48 49 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 47 def mrkdwn @mrkdwn end |
#reply_broadcast ⇒ Object
Also post thread replies to the channel.
38 39 40 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 38 def reply_broadcast @reply_broadcast end |
#tags ⇒ Object
Tags for message categorisation.
53 54 55 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 53 def @tags end |
#text ⇒ Object
Message text. Supports Slack markdown when ‘mrkdwn` is true.
26 27 28 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 26 def text @text end |
#thread_ts ⇒ Object
Thread timestamp to reply in a thread.
35 36 37 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 35 def thread_ts @thread_ts end |
#unfurl_links ⇒ Object
Enable link previews.
41 42 43 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 41 def unfurl_links @unfurl_links end |
#unfurl_media ⇒ Object
Enable media previews.
44 45 46 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 44 def unfurl_media @unfurl_media end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 253 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Zyphr.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 56 def self.attribute_map { :'connection_id' => :'connection_id', :'channel' => :'channel', :'text' => :'text', :'blocks' => :'blocks', :'attachments' => :'attachments', :'thread_ts' => :'thread_ts', :'reply_broadcast' => :'reply_broadcast', :'unfurl_links' => :'unfurl_links', :'unfurl_media' => :'unfurl_media', :'mrkdwn' => :'mrkdwn', :'metadata' => :'metadata', :'tags' => :'tags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 229 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 102 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 84 def self.openapi_types { :'connection_id' => :'String', :'channel' => :'String', :'text' => :'String', :'blocks' => :'Array<Hash<String, Object>>', :'attachments' => :'Array<Hash<String, Object>>', :'thread_ts' => :'String', :'reply_broadcast' => :'Boolean', :'unfurl_links' => :'Boolean', :'unfurl_media' => :'Boolean', :'mrkdwn' => :'Boolean', :'metadata' => :'Hash<String, Object>', :'tags' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 197 def ==(o) return true if self.equal?(o) self.class == o.class && connection_id == o.connection_id && channel == o.channel && text == o.text && blocks == o.blocks && == o. && thread_ts == o.thread_ts && reply_broadcast == o.reply_broadcast && unfurl_links == o.unfurl_links && unfurl_media == o.unfurl_media && mrkdwn == o.mrkdwn && == o. && == o. end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 324 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
216 217 218 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 216 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
222 223 224 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 222 def hash [connection_id, channel, text, blocks, , thread_ts, reply_broadcast, unfurl_links, unfurl_media, mrkdwn, , ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
182 183 184 185 186 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 182 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
300 301 302 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 300 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 306 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
294 295 296 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 294 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
190 191 192 193 |
# File 'lib/zyphr/models/send_slack_message_request.rb', line 190 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |