Class: Zyphr::SlackApi
- Inherits:
-
Object
- Object
- Zyphr::SlackApi
- Defined in:
- lib/zyphr/api/slack_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_slack_message(id, opts = {}) ⇒ SlackMessageResponse
Get a Slack message Retrieve a single Slack message by ID, including its full block/attachment payload and status timestamps.
-
#get_slack_message_with_http_info(id, opts = {}) ⇒ Array<(SlackMessageResponse, Integer, Hash)>
Get a Slack message Retrieve a single Slack message by ID, including its full block/attachment payload and status timestamps.
-
#initialize(api_client = ApiClient.default) ⇒ SlackApi
constructor
A new instance of SlackApi.
-
#list_slack_messages(opts = {}) ⇒ SlackMessageListResponse
List Slack messages List Slack messages sent through the project, with optional filtering by connection, channel, and status.
-
#list_slack_messages_with_http_info(opts = {}) ⇒ Array<(SlackMessageListResponse, Integer, Hash)>
List Slack messages List Slack messages sent through the project, with optional filtering by connection, channel, and status.
-
#send_slack_message(send_slack_message_request, opts = {}) ⇒ SendSlackMessageResponse
Send a Slack message Send a message to a Slack channel through a connected Slack workspace.
-
#send_slack_message_with_http_info(send_slack_message_request, opts = {}) ⇒ Array<(SendSlackMessageResponse, Integer, Hash)>
Send a Slack message Send a message to a Slack channel through a connected Slack workspace.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zyphr/api/slack_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_slack_message(id, opts = {}) ⇒ SlackMessageResponse
Get a Slack message Retrieve a single Slack message by ID, including its full block/attachment payload and status timestamps.
27 28 29 30 |
# File 'lib/zyphr/api/slack_api.rb', line 27 def (id, opts = {}) data, _status_code, _headers = (id, opts) data end |
#get_slack_message_with_http_info(id, opts = {}) ⇒ Array<(SlackMessageResponse, Integer, Hash)>
Get a Slack message Retrieve a single Slack message by ID, including its full block/attachment payload and status timestamps.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/zyphr/api/slack_api.rb', line 37 def (id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SlackApi.get_slack_message ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SlackApi.get_slack_message" end # resource path local_var_path = '/slack/messages/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SlackMessageResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"SlackApi.get_slack_message", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SlackApi#get_slack_message\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_slack_messages(opts = {}) ⇒ SlackMessageListResponse
List Slack messages List Slack messages sent through the project, with optional filtering by connection, channel, and status.
94 95 96 97 |
# File 'lib/zyphr/api/slack_api.rb', line 94 def (opts = {}) data, _status_code, _headers = (opts) data end |
#list_slack_messages_with_http_info(opts = {}) ⇒ Array<(SlackMessageListResponse, Integer, Hash)>
List Slack messages List Slack messages sent through the project, with optional filtering by connection, channel, and status.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/zyphr/api/slack_api.rb', line 108 def (opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SlackApi.list_slack_messages ...' end allowable_values = ["queued", "sending", "sent", "delivered", "failed"] if @api_client.config.client_side_validation && opts[:'status'] && !allowable_values.include?(opts[:'status']) fail ArgumentError, "invalid value for \"status\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 200 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling SlackApi.list_slack_messages, must be smaller than or equal to 200.' end # resource path local_var_path = '/slack/messages' # query parameters query_params = opts[:query_params] || {} query_params[:'connection_id'] = opts[:'connection_id'] if !opts[:'connection_id'].nil? query_params[:'channel_id'] = opts[:'channel_id'] if !opts[:'channel_id'].nil? query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SlackMessageListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"SlackApi.list_slack_messages", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SlackApi#list_slack_messages\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#send_slack_message(send_slack_message_request, opts = {}) ⇒ SendSlackMessageResponse
Send a Slack message Send a message to a Slack channel through a connected Slack workspace. Either ‘text` or `blocks` must be provided. If `connection_id` is omitted, the project’s active Slack connection is used. If ‘channel` is omitted, the connection’s default channel is used.
170 171 172 173 |
# File 'lib/zyphr/api/slack_api.rb', line 170 def (, opts = {}) data, _status_code, _headers = (, opts) data end |
#send_slack_message_with_http_info(send_slack_message_request, opts = {}) ⇒ Array<(SendSlackMessageResponse, Integer, Hash)>
Send a Slack message Send a message to a Slack channel through a connected Slack workspace. Either `text` or `blocks` must be provided. If `connection_id` is omitted, the project's active Slack connection is used. If `channel` is omitted, the connection's default channel is used.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/zyphr/api/slack_api.rb', line 180 def (, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SlackApi.send_slack_message ...' end # verify the required parameter 'send_slack_message_request' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'send_slack_message_request' when calling SlackApi.send_slack_message" end # resource path local_var_path = '/slack/send' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body() # return_type return_type = opts[:debug_return_type] || 'SendSlackMessageResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"SlackApi.send_slack_message", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SlackApi#send_slack_message\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |