Class: Zyphr::TemplatesApi
- Inherits:
-
Object
- Object
- Zyphr::TemplatesApi
- Defined in:
- lib/zyphr/api/templates_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_template(create_template_request, opts = {}) ⇒ TemplateResponse
Create template Create a new email template.
-
#create_template_with_http_info(create_template_request, opts = {}) ⇒ Array<(TemplateResponse, Integer, Hash)>
Create template Create a new email template.
-
#delete_template(id, opts = {}) ⇒ DeleteResult
Delete template Permanently delete a template.
-
#delete_template_with_http_info(id, opts = {}) ⇒ Array<(DeleteResult, Integer, Hash)>
Delete template Permanently delete a template.
-
#get_template(id, opts = {}) ⇒ TemplateResponse
Get template Get a specific template by ID.
-
#get_template_with_http_info(id, opts = {}) ⇒ Array<(TemplateResponse, Integer, Hash)>
Get template Get a specific template by ID.
-
#initialize(api_client = ApiClient.default) ⇒ TemplatesApi
constructor
A new instance of TemplatesApi.
-
#list_templates(opts = {}) ⇒ TemplateListResponse
List templates List templates for the account with optional pagination.
-
#list_templates_with_http_info(opts = {}) ⇒ Array<(TemplateListResponse, Integer, Hash)>
List templates List templates for the account with optional pagination.
-
#render_template(id, render_template_request, opts = {}) ⇒ TemplateRenderResponse
Render template Render a template with provided variables to preview the output.
-
#render_template_with_http_info(id, render_template_request, opts = {}) ⇒ Array<(TemplateRenderResponse, Integer, Hash)>
Render template Render a template with provided variables to preview the output.
-
#update_template(id, update_template_request, opts = {}) ⇒ TemplateResponse
Update template Update an existing template.
-
#update_template_with_http_info(id, update_template_request, opts = {}) ⇒ Array<(TemplateResponse, Integer, Hash)>
Update template Update an existing template.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TemplatesApi
Returns a new instance of TemplatesApi.
19 20 21 |
# File 'lib/zyphr/api/templates_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zyphr/api/templates_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_template(create_template_request, opts = {}) ⇒ TemplateResponse
Create template Create a new email template. Name must be unique within the account.
27 28 29 30 |
# File 'lib/zyphr/api/templates_api.rb', line 27 def create_template(create_template_request, opts = {}) data, _status_code, _headers = create_template_with_http_info(create_template_request, opts) data end |
#create_template_with_http_info(create_template_request, opts = {}) ⇒ Array<(TemplateResponse, Integer, Hash)>
Create template Create a new email template. Name must be unique within the account.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zyphr/api/templates_api.rb', line 37 def create_template_with_http_info(create_template_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TemplatesApi.create_template ...' end # verify the required parameter 'create_template_request' is set if @api_client.config.client_side_validation && create_template_request.nil? fail ArgumentError, "Missing the required parameter 'create_template_request' when calling TemplatesApi.create_template" end # resource path local_var_path = '/templates' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_template_request) # return_type return_type = opts[:debug_return_type] || 'TemplateResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"TemplatesApi.create_template", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TemplatesApi#create_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_template(id, opts = {}) ⇒ DeleteResult
Delete template Permanently delete a template.
95 96 97 98 |
# File 'lib/zyphr/api/templates_api.rb', line 95 def delete_template(id, opts = {}) data, _status_code, _headers = delete_template_with_http_info(id, opts) data end |
#delete_template_with_http_info(id, opts = {}) ⇒ Array<(DeleteResult, Integer, Hash)>
Delete template Permanently delete a template.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/zyphr/api/templates_api.rb', line 105 def delete_template_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TemplatesApi.delete_template ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling TemplatesApi.delete_template" end # resource path local_var_path = '/templates/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DeleteResult' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"TemplatesApi.delete_template", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TemplatesApi#delete_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_template(id, opts = {}) ⇒ TemplateResponse
Get template Get a specific template by ID.
158 159 160 161 |
# File 'lib/zyphr/api/templates_api.rb', line 158 def get_template(id, opts = {}) data, _status_code, _headers = get_template_with_http_info(id, opts) data end |
#get_template_with_http_info(id, opts = {}) ⇒ Array<(TemplateResponse, Integer, Hash)>
Get template Get a specific template by ID.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/zyphr/api/templates_api.rb', line 168 def get_template_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TemplatesApi.get_template ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling TemplatesApi.get_template" end # resource path local_var_path = '/templates/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TemplateResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"TemplatesApi.get_template", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TemplatesApi#get_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_templates(opts = {}) ⇒ TemplateListResponse
List templates List templates for the account with optional pagination.
222 223 224 225 |
# File 'lib/zyphr/api/templates_api.rb', line 222 def list_templates(opts = {}) data, _status_code, _headers = list_templates_with_http_info(opts) data end |
#list_templates_with_http_info(opts = {}) ⇒ Array<(TemplateListResponse, Integer, Hash)>
List templates List templates for the account with optional pagination.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/zyphr/api/templates_api.rb', line 233 def list_templates_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TemplatesApi.list_templates ...' end # resource path local_var_path = '/templates' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TemplateListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"TemplatesApi.list_templates", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TemplatesApi#list_templates\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#render_template(id, render_template_request, opts = {}) ⇒ TemplateRenderResponse
Render template Render a template with provided variables to preview the output.
285 286 287 288 |
# File 'lib/zyphr/api/templates_api.rb', line 285 def render_template(id, render_template_request, opts = {}) data, _status_code, _headers = render_template_with_http_info(id, render_template_request, opts) data end |
#render_template_with_http_info(id, render_template_request, opts = {}) ⇒ Array<(TemplateRenderResponse, Integer, Hash)>
Render template Render a template with provided variables to preview the output.
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/zyphr/api/templates_api.rb', line 296 def render_template_with_http_info(id, render_template_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TemplatesApi.render_template ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling TemplatesApi.render_template" end # verify the required parameter 'render_template_request' is set if @api_client.config.client_side_validation && render_template_request.nil? fail ArgumentError, "Missing the required parameter 'render_template_request' when calling TemplatesApi.render_template" end # resource path local_var_path = '/templates/{id}/render'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(render_template_request) # return_type return_type = opts[:debug_return_type] || 'TemplateRenderResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"TemplatesApi.render_template", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TemplatesApi#render_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_template(id, update_template_request, opts = {}) ⇒ TemplateResponse
Update template Update an existing template. Only provided fields are changed.
359 360 361 362 |
# File 'lib/zyphr/api/templates_api.rb', line 359 def update_template(id, update_template_request, opts = {}) data, _status_code, _headers = update_template_with_http_info(id, update_template_request, opts) data end |
#update_template_with_http_info(id, update_template_request, opts = {}) ⇒ Array<(TemplateResponse, Integer, Hash)>
Update template Update an existing template. Only provided fields are changed.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/zyphr/api/templates_api.rb', line 370 def update_template_with_http_info(id, update_template_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TemplatesApi.update_template ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling TemplatesApi.update_template" end # verify the required parameter 'update_template_request' is set if @api_client.config.client_side_validation && update_template_request.nil? fail ArgumentError, "Missing the required parameter 'update_template_request' when calling TemplatesApi.update_template" end # resource path local_var_path = '/templates/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_template_request) # return_type return_type = opts[:debug_return_type] || 'TemplateResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"TemplatesApi.update_template", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TemplatesApi#update_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |