Class: Zyphr::UtilityApi
- Inherits:
-
Object
- Object
- Zyphr::UtilityApi
- Defined in:
- lib/zyphr/api/utility_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#check_password_strength(password_strength_request, opts = {}) ⇒ PasswordStrengthResponse
Check password strength Pre-submit password check for a live registration/reset experience.
-
#check_password_strength_with_http_info(password_strength_request, opts = {}) ⇒ Array<(PasswordStrengthResponse, Integer, Hash)>
Check password strength Pre-submit password check for a live registration/reset experience.
-
#get_password_requirements(opts = {}) ⇒ PasswordRequirementsResponse
Get password requirements Get password requirements for the application.
-
#get_password_requirements_with_http_info(opts = {}) ⇒ Array<(PasswordRequirementsResponse, Integer, Hash)>
Get password requirements Get password requirements for the application.
-
#initialize(api_client = ApiClient.default) ⇒ UtilityApi
constructor
A new instance of UtilityApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ UtilityApi
Returns a new instance of UtilityApi.
19 20 21 |
# File 'lib/zyphr/api/utility_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zyphr/api/utility_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#check_password_strength(password_strength_request, opts = {}) ⇒ PasswordStrengthResponse
Check password strength
Pre-submit password check for a live registration/reset experience. Returns whether the password would be accepted by the server (valid), a strength score (0-100) and label, and actionable feedback. When an email is supplied, a password that resembles the email's local-part is flagged and marked invalid. The password is never logged or persisted.
27 28 29 30 |
# File 'lib/zyphr/api/utility_api.rb', line 27 def check_password_strength(password_strength_request, opts = {}) data, _status_code, _headers = check_password_strength_with_http_info(password_strength_request, opts) data end |
#check_password_strength_with_http_info(password_strength_request, opts = {}) ⇒ Array<(PasswordStrengthResponse, Integer, Hash)>
Check password strength Pre-submit password check for a live registration/reset experience. Returns whether the password would be accepted by the server (`valid`), a strength `score` (0-100) and `label`, and actionable `feedback`. When an `email` is supplied, a password that resembles the email's local-part is flagged and marked invalid. The password is never logged or persisted.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zyphr/api/utility_api.rb', line 37 def check_password_strength_with_http_info(password_strength_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UtilityApi.check_password_strength ...' end # verify the required parameter 'password_strength_request' is set if @api_client.config.client_side_validation && password_strength_request.nil? fail ArgumentError, "Missing the required parameter 'password_strength_request' when calling UtilityApi.check_password_strength" end # resource path local_var_path = '/auth/password-strength' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(password_strength_request) # return_type return_type = opts[:debug_return_type] || 'PasswordStrengthResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationPublicKey'] = opts.merge( :operation => :"UtilityApi.check_password_strength", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UtilityApi#check_password_strength\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_password_requirements(opts = {}) ⇒ PasswordRequirementsResponse
Get password requirements
Get password requirements for the application. Returns both a structured policy object (for driving a live requirements checklist) and human-readable requirements display strings. Useful for client-side validation before registration.
94 95 96 97 |
# File 'lib/zyphr/api/utility_api.rb', line 94 def get_password_requirements(opts = {}) data, _status_code, _headers = get_password_requirements_with_http_info(opts) data end |
#get_password_requirements_with_http_info(opts = {}) ⇒ Array<(PasswordRequirementsResponse, Integer, Hash)>
Get password requirements Get password requirements for the application. Returns both a structured `policy` object (for driving a live requirements checklist) and human-readable `requirements` display strings. Useful for client-side validation before registration.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/zyphr/api/utility_api.rb', line 103 def get_password_requirements_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UtilityApi.get_password_requirements ...' end # resource path local_var_path = '/auth/password-requirements' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PasswordRequirementsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationPublicKey'] = opts.merge( :operation => :"UtilityApi.get_password_requirements", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UtilityApi#get_password_requirements\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |