Class: Zyphr::WaaSDelivery
- Inherits:
-
Object
- Object
- Zyphr::WaaSDelivery
- Defined in:
- lib/zyphr/models/waa_s_delivery.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#application_id ⇒ Object
Returns the value of attribute application_id.
-
#attempts ⇒ Object
Returns the value of attribute attempts.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#endpoint_id ⇒ Object
Returns the value of attribute endpoint_id.
-
#event_id ⇒ Object
Returns the value of attribute event_id.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#id ⇒ Object
Returns the value of attribute id.
-
#last_attempt_at ⇒ Object
Returns the value of attribute last_attempt_at.
-
#next_retry_at ⇒ Object
Returns the value of attribute next_retry_at.
-
#status ⇒ Object
Returns the value of attribute status.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WaaSDelivery
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ WaaSDelivery
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zyphr::WaaSDelivery` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zyphr::WaaSDelivery`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] end if attributes.key?(:'endpoint_id') self.endpoint_id = attributes[:'endpoint_id'] end if attributes.key?(:'event_id') self.event_id = attributes[:'event_id'] end if attributes.key?(:'event_type') self.event_type = attributes[:'event_type'] end if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'attempts') self.attempts = attributes[:'attempts'] end if attributes.key?(:'last_attempt_at') self.last_attempt_at = attributes[:'last_attempt_at'] end if attributes.key?(:'next_retry_at') self.next_retry_at = attributes[:'next_retry_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#application_id ⇒ Object
Returns the value of attribute application_id.
20 21 22 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 20 def application_id @application_id end |
#attempts ⇒ Object
Returns the value of attribute attempts.
32 33 34 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 32 def attempts @attempts end |
#created_at ⇒ Object
Returns the value of attribute created_at.
38 39 40 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 38 def created_at @created_at end |
#endpoint_id ⇒ Object
Returns the value of attribute endpoint_id.
22 23 24 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 22 def endpoint_id @endpoint_id end |
#event_id ⇒ Object
Returns the value of attribute event_id.
24 25 26 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 24 def event_id @event_id end |
#event_type ⇒ Object
Returns the value of attribute event_type.
26 27 28 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 26 def event_type @event_type end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 18 def id @id end |
#last_attempt_at ⇒ Object
Returns the value of attribute last_attempt_at.
34 35 36 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 34 def last_attempt_at @last_attempt_at end |
#next_retry_at ⇒ Object
Returns the value of attribute next_retry_at.
36 37 38 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 36 def next_retry_at @next_retry_at end |
#status ⇒ Object
Returns the value of attribute status.
30 31 32 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 30 def status @status end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
28 29 30 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 28 def tenant_id @tenant_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 257 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Zyphr.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
80 81 82 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 80 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 85 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 63 def self.attribute_map { :'id' => :'id', :'application_id' => :'application_id', :'endpoint_id' => :'endpoint_id', :'event_id' => :'event_id', :'event_type' => :'event_type', :'tenant_id' => :'tenant_id', :'status' => :'status', :'attempts' => :'attempts', :'last_attempt_at' => :'last_attempt_at', :'next_retry_at' => :'next_retry_at', :'created_at' => :'created_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 233 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 107 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 90 def self.openapi_types { :'id' => :'String', :'application_id' => :'String', :'endpoint_id' => :'String', :'event_id' => :'String', :'event_type' => :'String', :'tenant_id' => :'String', :'status' => :'String', :'attempts' => :'Integer', :'last_attempt_at' => :'Time', :'next_retry_at' => :'Time', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 202 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && application_id == o.application_id && endpoint_id == o.endpoint_id && event_id == o.event_id && event_type == o.event_type && tenant_id == o.tenant_id && status == o.status && attempts == o.attempts && last_attempt_at == o.last_attempt_at && next_retry_at == o.next_retry_at && created_at == o.created_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 328 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
220 221 222 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 220 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
226 227 228 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 226 def hash [id, application_id, endpoint_id, event_id, event_type, tenant_id, status, attempts, last_attempt_at, next_retry_at, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 179 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 175 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
304 305 306 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 304 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 310 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
298 299 300 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 298 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
183 184 185 186 187 188 |
# File 'lib/zyphr/models/waa_s_delivery.rb', line 183 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["pending", "delivering", "delivered", "failed", "retrying", "exhausted"]) return false unless status_validator.valid?(@status) true end |