Class: Zyphr::WaaSEventsApi
- Inherits:
-
Object
- Object
- Zyphr::WaaSEventsApi
- Defined in:
- lib/zyphr/api/waa_s_events_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#batch_publish_waa_s_events(app_id, waa_s_batch_publish_request, opts = {}) ⇒ BatchPublishWaaSEvents201Response
Batch publish events Publish up to 100 events in a single request.
-
#batch_publish_waa_s_events_with_http_info(app_id, waa_s_batch_publish_request, opts = {}) ⇒ Array<(BatchPublishWaaSEvents201Response, Integer, Hash)>
Batch publish events Publish up to 100 events in a single request.
-
#initialize(api_client = ApiClient.default) ⇒ WaaSEventsApi
constructor
A new instance of WaaSEventsApi.
-
#publish_waa_s_event(app_id, waa_s_publish_event_request, opts = {}) ⇒ PublishWaaSEvent201Response
Publish an event Publish an event to all subscribed endpoints for the specified tenant.
-
#publish_waa_s_event_with_http_info(app_id, waa_s_publish_event_request, opts = {}) ⇒ Array<(PublishWaaSEvent201Response, Integer, Hash)>
Publish an event Publish an event to all subscribed endpoints for the specified tenant.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WaaSEventsApi
Returns a new instance of WaaSEventsApi.
19 20 21 |
# File 'lib/zyphr/api/waa_s_events_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zyphr/api/waa_s_events_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#batch_publish_waa_s_events(app_id, waa_s_batch_publish_request, opts = {}) ⇒ BatchPublishWaaSEvents201Response
Batch publish events Publish up to 100 events in a single request. Requires Starter plan or higher.
28 29 30 31 |
# File 'lib/zyphr/api/waa_s_events_api.rb', line 28 def batch_publish_waa_s_events(app_id, waa_s_batch_publish_request, opts = {}) data, _status_code, _headers = batch_publish_waa_s_events_with_http_info(app_id, waa_s_batch_publish_request, opts) data end |
#batch_publish_waa_s_events_with_http_info(app_id, waa_s_batch_publish_request, opts = {}) ⇒ Array<(BatchPublishWaaSEvents201Response, Integer, Hash)>
Batch publish events Publish up to 100 events in a single request. Requires Starter plan or higher.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/zyphr/api/waa_s_events_api.rb', line 39 def batch_publish_waa_s_events_with_http_info(app_id, waa_s_batch_publish_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WaaSEventsApi.batch_publish_waa_s_events ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling WaaSEventsApi.batch_publish_waa_s_events" end # verify the required parameter 'waa_s_batch_publish_request' is set if @api_client.config.client_side_validation && waa_s_batch_publish_request.nil? fail ArgumentError, "Missing the required parameter 'waa_s_batch_publish_request' when calling WaaSEventsApi.batch_publish_waa_s_events" end # resource path local_var_path = '/v1/waas/applications/{appId}/events/batch'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(waa_s_batch_publish_request) # return_type return_type = opts[:debug_return_type] || 'BatchPublishWaaSEvents201Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WaaSEventsApi.batch_publish_waa_s_events", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WaaSEventsApi#batch_publish_waa_s_events\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#publish_waa_s_event(app_id, waa_s_publish_event_request, opts = {}) ⇒ PublishWaaSEvent201Response
Publish an event Publish an event to all subscribed endpoints for the specified tenant. Zyphr creates delivery records and queues them for delivery.
102 103 104 105 |
# File 'lib/zyphr/api/waa_s_events_api.rb', line 102 def publish_waa_s_event(app_id, waa_s_publish_event_request, opts = {}) data, _status_code, _headers = publish_waa_s_event_with_http_info(app_id, waa_s_publish_event_request, opts) data end |
#publish_waa_s_event_with_http_info(app_id, waa_s_publish_event_request, opts = {}) ⇒ Array<(PublishWaaSEvent201Response, Integer, Hash)>
Publish an event Publish an event to all subscribed endpoints for the specified tenant. Zyphr creates delivery records and queues them for delivery.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/zyphr/api/waa_s_events_api.rb', line 113 def publish_waa_s_event_with_http_info(app_id, waa_s_publish_event_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WaaSEventsApi.publish_waa_s_event ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling WaaSEventsApi.publish_waa_s_event" end # verify the required parameter 'waa_s_publish_event_request' is set if @api_client.config.client_side_validation && waa_s_publish_event_request.nil? fail ArgumentError, "Missing the required parameter 'waa_s_publish_event_request' when calling WaaSEventsApi.publish_waa_s_event" end # resource path local_var_path = '/v1/waas/applications/{appId}/events'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(waa_s_publish_event_request) # return_type return_type = opts[:debug_return_type] || 'PublishWaaSEvent201Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WaaSEventsApi.publish_waa_s_event", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WaaSEventsApi#publish_waa_s_event\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |