Class: Zyphr::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/zyphr/models/workflow.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Workflow

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/zyphr/models/workflow.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zyphr::Workflow` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zyphr::Workflow`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'is_critical')
    self.is_critical = attributes[:'is_critical']
  else
    self.is_critical = nil
  end

  if attributes.key?(:'trigger_schema')
    if (value = attributes[:'trigger_schema']).is_a?(Hash)
      self.trigger_schema = value
    end
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'step_count')
    self.step_count = attributes[:'step_count']
  end

  if attributes.key?(:'steps')
    if (value = attributes[:'steps']).is_a?(Array)
      self.steps = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



20
21
22
# File 'lib/zyphr/models/workflow.rb', line 20

def 
  @account_id
end

#created_atObject

Returns the value of attribute created_at.



43
44
45
# File 'lib/zyphr/models/workflow.rb', line 43

def created_at
  @created_at
end

#descriptionObject

Returns the value of attribute description.



27
28
29
# File 'lib/zyphr/models/workflow.rb', line 27

def description
  @description
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zyphr/models/workflow.rb', line 18

def id
  @id
end

#is_criticalObject

Returns the value of attribute is_critical.



31
32
33
# File 'lib/zyphr/models/workflow.rb', line 31

def is_critical
  @is_critical
end

#keyObject

Unique workflow key within the project.



23
24
25
# File 'lib/zyphr/models/workflow.rb', line 23

def key
  @key
end

#nameObject

Returns the value of attribute name.



25
26
27
# File 'lib/zyphr/models/workflow.rb', line 25

def name
  @name
end

#statusObject

Returns the value of attribute status.



29
30
31
# File 'lib/zyphr/models/workflow.rb', line 29

def status
  @status
end

#step_countObject

Number of steps in the workflow (present in list responses).



38
39
40
# File 'lib/zyphr/models/workflow.rb', line 38

def step_count
  @step_count
end

#stepsObject

Ordered workflow steps (present when fetching a single workflow).



41
42
43
# File 'lib/zyphr/models/workflow.rb', line 41

def steps
  @steps
end

#tagsObject

Returns the value of attribute tags.



35
36
37
# File 'lib/zyphr/models/workflow.rb', line 35

def tags
  @tags
end

#trigger_schemaObject

Returns the value of attribute trigger_schema.



33
34
35
# File 'lib/zyphr/models/workflow.rb', line 33

def trigger_schema
  @trigger_schema
end

#updated_atObject

Returns the value of attribute updated_at.



45
46
47
# File 'lib/zyphr/models/workflow.rb', line 45

def updated_at
  @updated_at
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
# File 'lib/zyphr/models/workflow.rb', line 427

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Zyphr.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



89
90
91
# File 'lib/zyphr/models/workflow.rb', line 89

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



94
95
96
# File 'lib/zyphr/models/workflow.rb', line 94

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/zyphr/models/workflow.rb', line 70

def self.attribute_map
  {
    :'id' => :'id',
    :'account_id' => :'account_id',
    :'key' => :'key',
    :'name' => :'name',
    :'description' => :'description',
    :'status' => :'status',
    :'is_critical' => :'is_critical',
    :'trigger_schema' => :'trigger_schema',
    :'tags' => :'tags',
    :'step_count' => :'step_count',
    :'steps' => :'steps',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
# File 'lib/zyphr/models/workflow.rb', line 403

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



118
119
120
121
122
123
# File 'lib/zyphr/models/workflow.rb', line 118

def self.openapi_nullable
  Set.new([
    :'description',
    :'trigger_schema',
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/zyphr/models/workflow.rb', line 99

def self.openapi_types
  {
    :'id' => :'String',
    :'account_id' => :'String',
    :'key' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'status' => :'WorkflowStatus',
    :'is_critical' => :'Boolean',
    :'trigger_schema' => :'Hash<String, Object>',
    :'tags' => :'Array<String>',
    :'step_count' => :'Integer',
    :'steps' => :'Array<WorkflowStep>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/zyphr/models/workflow.rb', line 370

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
       == o. &&
      key == o.key &&
      name == o.name &&
      description == o.description &&
      status == o.status &&
      is_critical == o.is_critical &&
      trigger_schema == o.trigger_schema &&
      tags == o.tags &&
      step_count == o.step_count &&
      steps == o.steps &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



498
499
500
501
502
503
504
505
506
507
508
509
510
# File 'lib/zyphr/models/workflow.rb', line 498

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


390
391
392
# File 'lib/zyphr/models/workflow.rb', line 390

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



396
397
398
# File 'lib/zyphr/models/workflow.rb', line 396

def hash
  [id, , key, name, description, status, is_critical, trigger_schema, tags, step_count, steps, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/zyphr/models/workflow.rb', line 220

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @is_critical.nil?
    invalid_properties.push('invalid value for "is_critical", is_critical cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



474
475
476
# File 'lib/zyphr/models/workflow.rb', line 474

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/zyphr/models/workflow.rb', line 480

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



468
469
470
# File 'lib/zyphr/models/workflow.rb', line 468

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/zyphr/models/workflow.rb', line 264

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @account_id.nil?
  return false if @key.nil?
  return false if @name.nil?
  return false if @status.nil?
  return false if @is_critical.nil?
  return false if @tags.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end