Class: Zyphr::WorkflowExecution
- Inherits:
-
Object
- Object
- Zyphr::WorkflowExecution
- Defined in:
- lib/zyphr/models/workflow_execution.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#completed_at ⇒ Object
Returns the value of attribute completed_at.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#current_step_id ⇒ Object
Returns the value of attribute current_step_id.
-
#id ⇒ Object
Returns the value of attribute id.
-
#project_id ⇒ Object
Returns the value of attribute project_id.
-
#sender_from ⇒ Object
Returns the value of attribute sender_from.
-
#started_at ⇒ Object
Returns the value of attribute started_at.
-
#status ⇒ Object
Returns the value of attribute status.
-
#step_executions ⇒ Object
Returns the value of attribute step_executions.
-
#subscriber_id ⇒ Object
Returns the value of attribute subscriber_id.
-
#topic_key ⇒ Object
Returns the value of attribute topic_key.
-
#transaction_id ⇒ Object
Returns the value of attribute transaction_id.
-
#trigger_payload ⇒ Object
Returns the value of attribute trigger_payload.
-
#workflow_id ⇒ Object
Returns the value of attribute workflow_id.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkflowExecution
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ WorkflowExecution
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/zyphr/models/workflow_execution.rb', line 136 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zyphr::WorkflowExecution` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zyphr::WorkflowExecution`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'workflow_id') self.workflow_id = attributes[:'workflow_id'] else self.workflow_id = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] else self.project_id = nil end if attributes.key?(:'subscriber_id') self.subscriber_id = attributes[:'subscriber_id'] else self.subscriber_id = nil end if attributes.key?(:'topic_key') self.topic_key = attributes[:'topic_key'] end if attributes.key?(:'trigger_payload') if (value = attributes[:'trigger_payload']).is_a?(Hash) self.trigger_payload = value end end if attributes.key?(:'transaction_id') self.transaction_id = attributes[:'transaction_id'] end if attributes.key?(:'sender_from') self.sender_from = attributes[:'sender_from'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'current_step_id') self.current_step_id = attributes[:'current_step_id'] end if attributes.key?(:'step_executions') if (value = attributes[:'step_executions']).is_a?(Array) self.step_executions = value end end if attributes.key?(:'started_at') self.started_at = attributes[:'started_at'] end if attributes.key?(:'completed_at') self.completed_at = attributes[:'completed_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
22 23 24 |
# File 'lib/zyphr/models/workflow_execution.rb', line 22 def account_id @account_id end |
#completed_at ⇒ Object
Returns the value of attribute completed_at.
44 45 46 |
# File 'lib/zyphr/models/workflow_execution.rb', line 44 def completed_at @completed_at end |
#created_at ⇒ Object
Returns the value of attribute created_at.
46 47 48 |
# File 'lib/zyphr/models/workflow_execution.rb', line 46 def created_at @created_at end |
#current_step_id ⇒ Object
Returns the value of attribute current_step_id.
38 39 40 |
# File 'lib/zyphr/models/workflow_execution.rb', line 38 def current_step_id @current_step_id end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zyphr/models/workflow_execution.rb', line 18 def id @id end |
#project_id ⇒ Object
Returns the value of attribute project_id.
24 25 26 |
# File 'lib/zyphr/models/workflow_execution.rb', line 24 def project_id @project_id end |
#sender_from ⇒ Object
Returns the value of attribute sender_from.
34 35 36 |
# File 'lib/zyphr/models/workflow_execution.rb', line 34 def sender_from @sender_from end |
#started_at ⇒ Object
Returns the value of attribute started_at.
42 43 44 |
# File 'lib/zyphr/models/workflow_execution.rb', line 42 def started_at @started_at end |
#status ⇒ Object
Returns the value of attribute status.
36 37 38 |
# File 'lib/zyphr/models/workflow_execution.rb', line 36 def status @status end |
#step_executions ⇒ Object
Returns the value of attribute step_executions.
40 41 42 |
# File 'lib/zyphr/models/workflow_execution.rb', line 40 def step_executions @step_executions end |
#subscriber_id ⇒ Object
Returns the value of attribute subscriber_id.
26 27 28 |
# File 'lib/zyphr/models/workflow_execution.rb', line 26 def subscriber_id @subscriber_id end |
#topic_key ⇒ Object
Returns the value of attribute topic_key.
28 29 30 |
# File 'lib/zyphr/models/workflow_execution.rb', line 28 def topic_key @topic_key end |
#transaction_id ⇒ Object
Returns the value of attribute transaction_id.
32 33 34 |
# File 'lib/zyphr/models/workflow_execution.rb', line 32 def transaction_id @transaction_id end |
#trigger_payload ⇒ Object
Returns the value of attribute trigger_payload.
30 31 32 |
# File 'lib/zyphr/models/workflow_execution.rb', line 30 def trigger_payload @trigger_payload end |
#workflow_id ⇒ Object
Returns the value of attribute workflow_id.
20 21 22 |
# File 'lib/zyphr/models/workflow_execution.rb', line 20 def workflow_id @workflow_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/zyphr/models/workflow_execution.rb', line 410 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Zyphr.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
92 93 94 |
# File 'lib/zyphr/models/workflow_execution.rb', line 92 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
97 98 99 |
# File 'lib/zyphr/models/workflow_execution.rb', line 97 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/zyphr/models/workflow_execution.rb', line 71 def self.attribute_map { :'id' => :'id', :'workflow_id' => :'workflow_id', :'account_id' => :'account_id', :'project_id' => :'project_id', :'subscriber_id' => :'subscriber_id', :'topic_key' => :'topic_key', :'trigger_payload' => :'trigger_payload', :'transaction_id' => :'transaction_id', :'sender_from' => :'sender_from', :'status' => :'status', :'current_step_id' => :'current_step_id', :'step_executions' => :'step_executions', :'started_at' => :'started_at', :'completed_at' => :'completed_at', :'created_at' => :'created_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/zyphr/models/workflow_execution.rb', line 386 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
123 124 125 126 127 128 129 130 131 132 |
# File 'lib/zyphr/models/workflow_execution.rb', line 123 def self.openapi_nullable Set.new([ :'topic_key', :'transaction_id', :'sender_from', :'current_step_id', :'started_at', :'completed_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/zyphr/models/workflow_execution.rb', line 102 def self.openapi_types { :'id' => :'String', :'workflow_id' => :'String', :'account_id' => :'String', :'project_id' => :'String', :'subscriber_id' => :'String', :'topic_key' => :'String', :'trigger_payload' => :'Hash<String, Object>', :'transaction_id' => :'String', :'sender_from' => :'String', :'status' => :'WorkflowExecutionStatus', :'current_step_id' => :'String', :'step_executions' => :'Array<WorkflowStepExecution>', :'started_at' => :'Time', :'completed_at' => :'Time', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/zyphr/models/workflow_execution.rb', line 351 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && workflow_id == o.workflow_id && account_id == o.account_id && project_id == o.project_id && subscriber_id == o.subscriber_id && topic_key == o.topic_key && trigger_payload == o.trigger_payload && transaction_id == o.transaction_id && sender_from == o.sender_from && status == o.status && current_step_id == o.current_step_id && step_executions == o.step_executions && started_at == o.started_at && completed_at == o.completed_at && created_at == o.created_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/zyphr/models/workflow_execution.rb', line 481 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
373 374 375 |
# File 'lib/zyphr/models/workflow_execution.rb', line 373 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
379 380 381 |
# File 'lib/zyphr/models/workflow_execution.rb', line 379 def hash [id, workflow_id, account_id, project_id, subscriber_id, topic_key, trigger_payload, transaction_id, sender_from, status, current_step_id, step_executions, started_at, completed_at, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/zyphr/models/workflow_execution.rb', line 231 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @workflow_id.nil? invalid_properties.push('invalid value for "workflow_id", workflow_id cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @project_id.nil? invalid_properties.push('invalid value for "project_id", project_id cannot be nil.') end if @subscriber_id.nil? invalid_properties.push('invalid value for "subscriber_id", subscriber_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
457 458 459 |
# File 'lib/zyphr/models/workflow_execution.rb', line 457 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
463 464 465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/zyphr/models/workflow_execution.rb', line 463 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
451 452 453 |
# File 'lib/zyphr/models/workflow_execution.rb', line 451 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/zyphr/models/workflow_execution.rb', line 267 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @workflow_id.nil? return false if @account_id.nil? return false if @project_id.nil? return false if @subscriber_id.nil? return false if @status.nil? return false if @created_at.nil? true end |