Class: Zyphr::AuthEmailVerificationApi
- Inherits:
-
Object
- Object
- Zyphr::AuthEmailVerificationApi
- Defined in:
- lib/zyphr/api/auth_email_verification_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#confirm_email_verification(confirm_email_verification_request, opts = {}) ⇒ ConfirmEmailVerificationResponse
Confirm email verification Verify the user’s email using the token from the verification email.
-
#confirm_email_verification_with_http_info(confirm_email_verification_request, opts = {}) ⇒ Array<(ConfirmEmailVerificationResponse, Integer, Hash)>
Confirm email verification Verify the user's email using the token from the verification email.
-
#initialize(api_client = ApiClient.default) ⇒ AuthEmailVerificationApi
constructor
A new instance of AuthEmailVerificationApi.
-
#resend_email_verification(opts = {}) ⇒ SuccessResult
Resend email verification Resend the verification email to the authenticated user.
-
#resend_email_verification_with_http_info(opts = {}) ⇒ Array<(SuccessResult, Integer, Hash)>
Resend email verification Resend the verification email to the authenticated user.
-
#send_email_verification(opts = {}) ⇒ SuccessResult
Send email verification Send an email verification link to the authenticated user.
-
#send_email_verification_with_http_info(opts = {}) ⇒ Array<(SuccessResult, Integer, Hash)>
Send email verification Send an email verification link to the authenticated user.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AuthEmailVerificationApi
Returns a new instance of AuthEmailVerificationApi.
19 20 21 |
# File 'lib/zyphr/api/auth_email_verification_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zyphr/api/auth_email_verification_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#confirm_email_verification(confirm_email_verification_request, opts = {}) ⇒ ConfirmEmailVerificationResponse
Confirm email verification Verify the user’s email using the token from the verification email.
27 28 29 30 |
# File 'lib/zyphr/api/auth_email_verification_api.rb', line 27 def confirm_email_verification(confirm_email_verification_request, opts = {}) data, _status_code, _headers = confirm_email_verification_with_http_info(confirm_email_verification_request, opts) data end |
#confirm_email_verification_with_http_info(confirm_email_verification_request, opts = {}) ⇒ Array<(ConfirmEmailVerificationResponse, Integer, Hash)>
Confirm email verification Verify the user's email using the token from the verification email.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zyphr/api/auth_email_verification_api.rb', line 37 def confirm_email_verification_with_http_info(confirm_email_verification_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthEmailVerificationApi.confirm_email_verification ...' end # verify the required parameter 'confirm_email_verification_request' is set if @api_client.config.client_side_validation && confirm_email_verification_request.nil? fail ArgumentError, "Missing the required parameter 'confirm_email_verification_request' when calling AuthEmailVerificationApi.confirm_email_verification" end # resource path local_var_path = '/auth/verify-email/confirm' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(confirm_email_verification_request) # return_type return_type = opts[:debug_return_type] || 'ConfirmEmailVerificationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthEmailVerificationApi.confirm_email_verification", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthEmailVerificationApi#confirm_email_verification\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#resend_email_verification(opts = {}) ⇒ SuccessResult
Resend email verification Resend the verification email to the authenticated user. Rate limited to once per 60 seconds.
95 96 97 98 |
# File 'lib/zyphr/api/auth_email_verification_api.rb', line 95 def resend_email_verification(opts = {}) data, _status_code, _headers = resend_email_verification_with_http_info(opts) data end |
#resend_email_verification_with_http_info(opts = {}) ⇒ Array<(SuccessResult, Integer, Hash)>
Resend email verification Resend the verification email to the authenticated user. Rate limited to once per 60 seconds.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/zyphr/api/auth_email_verification_api.rb', line 105 def resend_email_verification_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthEmailVerificationApi.resend_email_verification ...' end # resource path local_var_path = '/auth/verify-email/resend' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'send_email_verification_request']) # return_type return_type = opts[:debug_return_type] || 'SuccessResult' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'EndUserToken', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthEmailVerificationApi.resend_email_verification", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthEmailVerificationApi#resend_email_verification\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#send_email_verification(opts = {}) ⇒ SuccessResult
Send email verification Send an email verification link to the authenticated user.
159 160 161 162 |
# File 'lib/zyphr/api/auth_email_verification_api.rb', line 159 def send_email_verification(opts = {}) data, _status_code, _headers = send_email_verification_with_http_info(opts) data end |
#send_email_verification_with_http_info(opts = {}) ⇒ Array<(SuccessResult, Integer, Hash)>
Send email verification Send an email verification link to the authenticated user.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/zyphr/api/auth_email_verification_api.rb', line 169 def send_email_verification_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthEmailVerificationApi.send_email_verification ...' end # resource path local_var_path = '/auth/verify-email/send' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'send_email_verification_request']) # return_type return_type = opts[:debug_return_type] || 'SuccessResult' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'EndUserToken', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthEmailVerificationApi.send_email_verification", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthEmailVerificationApi#send_email_verification\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |