Class: Zyphr::AuthRegistrationApi
- Inherits:
-
Object
- Object
- Zyphr::AuthRegistrationApi
- Defined in:
- lib/zyphr/api/auth_registration_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ AuthRegistrationApi
constructor
A new instance of AuthRegistrationApi.
-
#register_end_user(register_request, opts = {}) ⇒ AuthResultResponse
Register a new end user Register a new end user with email and password.
-
#register_end_user_with_http_info(register_request, opts = {}) ⇒ Array<(AuthResultResponse, Integer, Hash)>
Register a new end user Register a new end user with email and password.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AuthRegistrationApi
Returns a new instance of AuthRegistrationApi.
19 20 21 |
# File 'lib/zyphr/api/auth_registration_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zyphr/api/auth_registration_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#register_end_user(register_request, opts = {}) ⇒ AuthResultResponse
Register a new end user Register a new end user with email and password.
27 28 29 30 |
# File 'lib/zyphr/api/auth_registration_api.rb', line 27 def register_end_user(register_request, opts = {}) data, _status_code, _headers = register_end_user_with_http_info(register_request, opts) data end |
#register_end_user_with_http_info(register_request, opts = {}) ⇒ Array<(AuthResultResponse, Integer, Hash)>
Register a new end user Register a new end user with email and password.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zyphr/api/auth_registration_api.rb', line 37 def register_end_user_with_http_info(register_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthRegistrationApi.register_end_user ...' end # verify the required parameter 'register_request' is set if @api_client.config.client_side_validation && register_request.nil? fail ArgumentError, "Missing the required parameter 'register_request' when calling AuthRegistrationApi.register_end_user" end # resource path local_var_path = '/auth/users/register' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(register_request) # return_type return_type = opts[:debug_return_type] || 'AuthResultResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthRegistrationApi.register_end_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthRegistrationApi#register_end_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |