Class: Zyphr::AuthUserProfileApi
- Inherits:
-
Object
- Object
- Zyphr::AuthUserProfileApi
- Defined in:
- lib/zyphr/api/auth_user_profile_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#delete_end_user(opts = {}) ⇒ EndUserDeleteResponse
Delete current end user account Delete the current end user account (GDPR right to erasure).
-
#delete_end_user_with_http_info(opts = {}) ⇒ Array<(EndUserDeleteResponse, Integer, Hash)>
Delete current end user account Delete the current end user account (GDPR right to erasure).
-
#get_end_user(opts = {}) ⇒ AuthUserResponse
Get current end user profile Retrieve the profile of the currently authenticated end user.
-
#get_end_user_with_http_info(opts = {}) ⇒ Array<(AuthUserResponse, Integer, Hash)>
Get current end user profile Retrieve the profile of the currently authenticated end user.
-
#initialize(api_client = ApiClient.default) ⇒ AuthUserProfileApi
constructor
A new instance of AuthUserProfileApi.
-
#update_end_user(update_end_user_request, opts = {}) ⇒ AuthUserResponse
Update current end user profile Update the profile of the currently authenticated end user.
-
#update_end_user_with_http_info(update_end_user_request, opts = {}) ⇒ Array<(AuthUserResponse, Integer, Hash)>
Update current end user profile Update the profile of the currently authenticated end user.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AuthUserProfileApi
Returns a new instance of AuthUserProfileApi.
19 20 21 |
# File 'lib/zyphr/api/auth_user_profile_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zyphr/api/auth_user_profile_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#delete_end_user(opts = {}) ⇒ EndUserDeleteResponse
Delete current end user account Delete the current end user account (GDPR right to erasure). This is a soft delete — the account is marked as deleted but data is retained for a period to allow for recovery or legal requirements.
26 27 28 29 |
# File 'lib/zyphr/api/auth_user_profile_api.rb', line 26 def delete_end_user(opts = {}) data, _status_code, _headers = delete_end_user_with_http_info(opts) data end |
#delete_end_user_with_http_info(opts = {}) ⇒ Array<(EndUserDeleteResponse, Integer, Hash)>
Delete current end user account Delete the current end user account (GDPR right to erasure). This is a soft delete — the account is marked as deleted but data is retained for a period to allow for recovery or legal requirements.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/zyphr/api/auth_user_profile_api.rb', line 35 def delete_end_user_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthUserProfileApi.delete_end_user ...' end # resource path local_var_path = '/auth/users/me' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EndUserDeleteResponse' # auth_names auth_names = opts[:debug_auth_names] || ['EndUserToken', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthUserProfileApi.delete_end_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthUserProfileApi#delete_end_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_end_user(opts = {}) ⇒ AuthUserResponse
Get current end user profile Retrieve the profile of the currently authenticated end user.
83 84 85 86 |
# File 'lib/zyphr/api/auth_user_profile_api.rb', line 83 def get_end_user(opts = {}) data, _status_code, _headers = get_end_user_with_http_info(opts) data end |
#get_end_user_with_http_info(opts = {}) ⇒ Array<(AuthUserResponse, Integer, Hash)>
Get current end user profile Retrieve the profile of the currently authenticated end user.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/zyphr/api/auth_user_profile_api.rb', line 92 def get_end_user_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthUserProfileApi.get_end_user ...' end # resource path local_var_path = '/auth/users/me' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AuthUserResponse' # auth_names auth_names = opts[:debug_auth_names] || ['EndUserToken', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthUserProfileApi.get_end_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthUserProfileApi#get_end_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_end_user(update_end_user_request, opts = {}) ⇒ AuthUserResponse
Update current end user profile Update the profile of the currently authenticated end user.
141 142 143 144 |
# File 'lib/zyphr/api/auth_user_profile_api.rb', line 141 def update_end_user(update_end_user_request, opts = {}) data, _status_code, _headers = update_end_user_with_http_info(update_end_user_request, opts) data end |
#update_end_user_with_http_info(update_end_user_request, opts = {}) ⇒ Array<(AuthUserResponse, Integer, Hash)>
Update current end user profile Update the profile of the currently authenticated end user.
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/zyphr/api/auth_user_profile_api.rb', line 151 def update_end_user_with_http_info(update_end_user_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthUserProfileApi.update_end_user ...' end # verify the required parameter 'update_end_user_request' is set if @api_client.config.client_side_validation && update_end_user_request.nil? fail ArgumentError, "Missing the required parameter 'update_end_user_request' when calling AuthUserProfileApi.update_end_user" end # resource path local_var_path = '/auth/users/me' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_end_user_request) # return_type return_type = opts[:debug_return_type] || 'AuthUserResponse' # auth_names auth_names = opts[:debug_auth_names] || ['EndUserToken', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthUserProfileApi.update_end_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthUserProfileApi#update_end_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |