Class: Zyphr::AuthWebAuthnApi
- Inherits:
-
Object
- Object
- Zyphr::AuthWebAuthnApi
- Defined in:
- lib/zyphr/api/auth_web_authn_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#delete_web_authn_credential(id, opts = {}) ⇒ SuccessResult
Delete a WebAuthn credential Delete a WebAuthn credential by ID.
-
#delete_web_authn_credential_with_http_info(id, opts = {}) ⇒ Array<(SuccessResult, Integer, Hash)>
Delete a WebAuthn credential Delete a WebAuthn credential by ID.
-
#get_web_authn_status(opts = {}) ⇒ WebAuthnStatusResponse
Get WebAuthn status Check if WebAuthn is enabled for the authenticated user and get the credential count.
-
#get_web_authn_status_with_http_info(opts = {}) ⇒ Array<(WebAuthnStatusResponse, Integer, Hash)>
Get WebAuthn status Check if WebAuthn is enabled for the authenticated user and get the credential count.
-
#initialize(api_client = ApiClient.default) ⇒ AuthWebAuthnApi
constructor
A new instance of AuthWebAuthnApi.
-
#list_web_authn_credentials(opts = {}) ⇒ WebAuthnCredentialListResponse
List WebAuthn credentials List all WebAuthn credentials for the authenticated user.
-
#list_web_authn_credentials_with_http_info(opts = {}) ⇒ Array<(WebAuthnCredentialListResponse, Integer, Hash)>
List WebAuthn credentials List all WebAuthn credentials for the authenticated user.
-
#rename_web_authn_credential(id, rename_web_authn_credential_request, opts = {}) ⇒ WebAuthnCredentialResponse
Rename a WebAuthn credential Rename a WebAuthn credential by ID.
-
#rename_web_authn_credential_with_http_info(id, rename_web_authn_credential_request, opts = {}) ⇒ Array<(WebAuthnCredentialResponse, Integer, Hash)>
Rename a WebAuthn credential Rename a WebAuthn credential by ID.
-
#start_web_authn_authentication(opts = {}) ⇒ WebAuthnStartAuthResponse
Start WebAuthn authentication Start the WebAuthn authentication flow.
-
#start_web_authn_authentication_with_http_info(opts = {}) ⇒ Array<(WebAuthnStartAuthResponse, Integer, Hash)>
Start WebAuthn authentication Start the WebAuthn authentication flow.
-
#start_web_authn_registration(opts = {}) ⇒ WebAuthnStartRegistrationResponse
Start WebAuthn registration Start WebAuthn credential registration for an authenticated user.
-
#start_web_authn_registration_with_http_info(opts = {}) ⇒ Array<(WebAuthnStartRegistrationResponse, Integer, Hash)>
Start WebAuthn registration Start WebAuthn credential registration for an authenticated user.
-
#verify_web_authn_authentication(web_authn_verify_auth_request, opts = {}) ⇒ AuthLoginResponse
Verify WebAuthn authentication Complete WebAuthn authentication and issue tokens.
-
#verify_web_authn_authentication_with_http_info(web_authn_verify_auth_request, opts = {}) ⇒ Array<(AuthLoginResponse, Integer, Hash)>
Verify WebAuthn authentication Complete WebAuthn authentication and issue tokens.
-
#verify_web_authn_registration(web_authn_verify_registration_request, opts = {}) ⇒ WebAuthnVerifyRegistrationResponse
Verify WebAuthn registration Complete WebAuthn credential registration.
-
#verify_web_authn_registration_with_http_info(web_authn_verify_registration_request, opts = {}) ⇒ Array<(WebAuthnVerifyRegistrationResponse, Integer, Hash)>
Verify WebAuthn registration Complete WebAuthn credential registration.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AuthWebAuthnApi
Returns a new instance of AuthWebAuthnApi.
19 20 21 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#delete_web_authn_credential(id, opts = {}) ⇒ SuccessResult
Delete a WebAuthn credential Delete a WebAuthn credential by ID.
27 28 29 30 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 27 def delete_web_authn_credential(id, opts = {}) data, _status_code, _headers = delete_web_authn_credential_with_http_info(id, opts) data end |
#delete_web_authn_credential_with_http_info(id, opts = {}) ⇒ Array<(SuccessResult, Integer, Hash)>
Delete a WebAuthn credential Delete a WebAuthn credential by ID.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 37 def delete_web_authn_credential_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthWebAuthnApi.delete_web_authn_credential ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AuthWebAuthnApi.delete_web_authn_credential" end # resource path local_var_path = '/auth/webauthn/credentials/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SuccessResult' # auth_names auth_names = opts[:debug_auth_names] || ['EndUserToken', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthWebAuthnApi.delete_web_authn_credential", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthWebAuthnApi#delete_web_authn_credential\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_web_authn_status(opts = {}) ⇒ WebAuthnStatusResponse
Get WebAuthn status Check if WebAuthn is enabled for the authenticated user and get the credential count.
89 90 91 92 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 89 def get_web_authn_status(opts = {}) data, _status_code, _headers = get_web_authn_status_with_http_info(opts) data end |
#get_web_authn_status_with_http_info(opts = {}) ⇒ Array<(WebAuthnStatusResponse, Integer, Hash)>
Get WebAuthn status Check if WebAuthn is enabled for the authenticated user and get the credential count.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 98 def get_web_authn_status_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthWebAuthnApi.get_web_authn_status ...' end # resource path local_var_path = '/auth/webauthn/status' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WebAuthnStatusResponse' # auth_names auth_names = opts[:debug_auth_names] || ['EndUserToken', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthWebAuthnApi.get_web_authn_status", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthWebAuthnApi#get_web_authn_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_web_authn_credentials(opts = {}) ⇒ WebAuthnCredentialListResponse
List WebAuthn credentials List all WebAuthn credentials for the authenticated user.
146 147 148 149 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 146 def list_web_authn_credentials(opts = {}) data, _status_code, _headers = list_web_authn_credentials_with_http_info(opts) data end |
#list_web_authn_credentials_with_http_info(opts = {}) ⇒ Array<(WebAuthnCredentialListResponse, Integer, Hash)>
List WebAuthn credentials List all WebAuthn credentials for the authenticated user.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 155 def list_web_authn_credentials_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthWebAuthnApi.list_web_authn_credentials ...' end # resource path local_var_path = '/auth/webauthn/credentials' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WebAuthnCredentialListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['EndUserToken', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthWebAuthnApi.list_web_authn_credentials", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthWebAuthnApi#list_web_authn_credentials\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rename_web_authn_credential(id, rename_web_authn_credential_request, opts = {}) ⇒ WebAuthnCredentialResponse
Rename a WebAuthn credential Rename a WebAuthn credential by ID.
205 206 207 208 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 205 def rename_web_authn_credential(id, rename_web_authn_credential_request, opts = {}) data, _status_code, _headers = rename_web_authn_credential_with_http_info(id, rename_web_authn_credential_request, opts) data end |
#rename_web_authn_credential_with_http_info(id, rename_web_authn_credential_request, opts = {}) ⇒ Array<(WebAuthnCredentialResponse, Integer, Hash)>
Rename a WebAuthn credential Rename a WebAuthn credential by ID.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 216 def rename_web_authn_credential_with_http_info(id, rename_web_authn_credential_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthWebAuthnApi.rename_web_authn_credential ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AuthWebAuthnApi.rename_web_authn_credential" end # verify the required parameter 'rename_web_authn_credential_request' is set if @api_client.config.client_side_validation && rename_web_authn_credential_request.nil? fail ArgumentError, "Missing the required parameter 'rename_web_authn_credential_request' when calling AuthWebAuthnApi.rename_web_authn_credential" end # resource path local_var_path = '/auth/webauthn/credentials/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(rename_web_authn_credential_request) # return_type return_type = opts[:debug_return_type] || 'WebAuthnCredentialResponse' # auth_names auth_names = opts[:debug_auth_names] || ['EndUserToken', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthWebAuthnApi.rename_web_authn_credential", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthWebAuthnApi#rename_web_authn_credential\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#start_web_authn_authentication(opts = {}) ⇒ WebAuthnStartAuthResponse
Start WebAuthn authentication Start the WebAuthn authentication flow. Returns options to pass to navigator.credentials.get().
278 279 280 281 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 278 def start_web_authn_authentication(opts = {}) data, _status_code, _headers = start_web_authn_authentication_with_http_info(opts) data end |
#start_web_authn_authentication_with_http_info(opts = {}) ⇒ Array<(WebAuthnStartAuthResponse, Integer, Hash)>
Start WebAuthn authentication Start the WebAuthn authentication flow. Returns options to pass to navigator.credentials.get().
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 288 def start_web_authn_authentication_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthWebAuthnApi.start_web_authn_authentication ...' end # resource path local_var_path = '/auth/webauthn/authentication/start' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'web_authn_start_auth_request']) # return_type return_type = opts[:debug_return_type] || 'WebAuthnStartAuthResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthWebAuthnApi.start_web_authn_authentication", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthWebAuthnApi#start_web_authn_authentication\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#start_web_authn_registration(opts = {}) ⇒ WebAuthnStartRegistrationResponse
Start WebAuthn registration Start WebAuthn credential registration for an authenticated user. Returns options to pass to navigator.credentials.create().
342 343 344 345 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 342 def start_web_authn_registration(opts = {}) data, _status_code, _headers = start_web_authn_registration_with_http_info(opts) data end |
#start_web_authn_registration_with_http_info(opts = {}) ⇒ Array<(WebAuthnStartRegistrationResponse, Integer, Hash)>
Start WebAuthn registration Start WebAuthn credential registration for an authenticated user. Returns options to pass to navigator.credentials.create().
352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 352 def start_web_authn_registration_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthWebAuthnApi.start_web_authn_registration ...' end # resource path local_var_path = '/auth/webauthn/registration/start' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'web_authn_start_registration_request']) # return_type return_type = opts[:debug_return_type] || 'WebAuthnStartRegistrationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'EndUserToken', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthWebAuthnApi.start_web_authn_registration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthWebAuthnApi#start_web_authn_registration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#verify_web_authn_authentication(web_authn_verify_auth_request, opts = {}) ⇒ AuthLoginResponse
Verify WebAuthn authentication Complete WebAuthn authentication and issue tokens. If MFA is enabled, returns mfa_required with a challenge token.
406 407 408 409 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 406 def verify_web_authn_authentication(web_authn_verify_auth_request, opts = {}) data, _status_code, _headers = verify_web_authn_authentication_with_http_info(web_authn_verify_auth_request, opts) data end |
#verify_web_authn_authentication_with_http_info(web_authn_verify_auth_request, opts = {}) ⇒ Array<(AuthLoginResponse, Integer, Hash)>
Verify WebAuthn authentication Complete WebAuthn authentication and issue tokens. If MFA is enabled, returns mfa_required with a challenge token.
416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 416 def verify_web_authn_authentication_with_http_info(web_authn_verify_auth_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthWebAuthnApi.verify_web_authn_authentication ...' end # verify the required parameter 'web_authn_verify_auth_request' is set if @api_client.config.client_side_validation && web_authn_verify_auth_request.nil? fail ArgumentError, "Missing the required parameter 'web_authn_verify_auth_request' when calling AuthWebAuthnApi.verify_web_authn_authentication" end # resource path local_var_path = '/auth/webauthn/authentication/verify' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(web_authn_verify_auth_request) # return_type return_type = opts[:debug_return_type] || 'AuthLoginResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthWebAuthnApi.verify_web_authn_authentication", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthWebAuthnApi#verify_web_authn_authentication\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#verify_web_authn_registration(web_authn_verify_registration_request, opts = {}) ⇒ WebAuthnVerifyRegistrationResponse
Verify WebAuthn registration Complete WebAuthn credential registration. Stores the credential for future authentication.
474 475 476 477 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 474 def verify_web_authn_registration(web_authn_verify_registration_request, opts = {}) data, _status_code, _headers = verify_web_authn_registration_with_http_info(web_authn_verify_registration_request, opts) data end |
#verify_web_authn_registration_with_http_info(web_authn_verify_registration_request, opts = {}) ⇒ Array<(WebAuthnVerifyRegistrationResponse, Integer, Hash)>
Verify WebAuthn registration Complete WebAuthn credential registration. Stores the credential for future authentication.
484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 |
# File 'lib/zyphr/api/auth_web_authn_api.rb', line 484 def verify_web_authn_registration_with_http_info(web_authn_verify_registration_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthWebAuthnApi.verify_web_authn_registration ...' end # verify the required parameter 'web_authn_verify_registration_request' is set if @api_client.config.client_side_validation && web_authn_verify_registration_request.nil? fail ArgumentError, "Missing the required parameter 'web_authn_verify_registration_request' when calling AuthWebAuthnApi.verify_web_authn_registration" end # resource path local_var_path = '/auth/webauthn/registration/verify' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(web_authn_verify_registration_request) # return_type return_type = opts[:debug_return_type] || 'WebAuthnVerifyRegistrationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationSecret', 'EndUserToken', 'ApplicationPublicKey'] = opts.merge( :operation => :"AuthWebAuthnApi.verify_web_authn_registration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthWebAuthnApi#verify_web_authn_registration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |