Class: Zyphr::DomainsApi
- Inherits:
-
Object
- Object
- Zyphr::DomainsApi
- Defined in:
- lib/zyphr/api/domains_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#add_domain(add_domain_request, opts = {}) ⇒ AddDomain200Response
Add a sending domain Register a new sending domain on the account.
-
#add_domain_with_http_info(add_domain_request, opts = {}) ⇒ Array<(AddDomain200Response, Integer, Hash)>
Add a sending domain Register a new sending domain on the account.
-
#delete_domain(id, opts = {}) ⇒ DeleteDomainResponse
Remove a sending domain Remove a sending domain from the project.
-
#delete_domain_with_http_info(id, opts = {}) ⇒ Array<(DeleteDomainResponse, Integer, Hash)>
Remove a sending domain Remove a sending domain from the project.
-
#get_domain(id, opts = {}) ⇒ GetDomain200Response
Get a sending domain Retrieve a single sending domain by ID, including DNS records and verification counters.
-
#get_domain_verification_status(id, opts = {}) ⇒ VerificationStatusResponse
Get domain verification status Returns the current verification status with per-record ‘verified` flags and aggregate counters.
-
#get_domain_verification_status_with_http_info(id, opts = {}) ⇒ Array<(VerificationStatusResponse, Integer, Hash)>
Get domain verification status Returns the current verification status with per-record `verified` flags and aggregate counters.
-
#get_domain_with_http_info(id, opts = {}) ⇒ Array<(GetDomain200Response, Integer, Hash)>
Get a sending domain Retrieve a single sending domain by ID, including DNS records and verification counters.
-
#initialize(api_client = ApiClient.default) ⇒ DomainsApi
constructor
A new instance of DomainsApi.
-
#list_domains(opts = {}) ⇒ DomainListResponse
List sending domains List sending domains on the current project, with verification status and DNS records.
-
#list_domains_with_http_info(opts = {}) ⇒ Array<(DomainListResponse, Integer, Hash)>
List sending domains List sending domains on the current project, with verification status and DNS records.
-
#verify_domain(id, opts = {}) ⇒ VerifyDomainResponse
Trigger domain verification Queue an asynchronous DNS verification check.
-
#verify_domain_with_http_info(id, opts = {}) ⇒ Array<(VerifyDomainResponse, Integer, Hash)>
Trigger domain verification Queue an asynchronous DNS verification check.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ DomainsApi
Returns a new instance of DomainsApi.
19 20 21 |
# File 'lib/zyphr/api/domains_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zyphr/api/domains_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#add_domain(add_domain_request, opts = {}) ⇒ AddDomain200Response
Add a sending domain Register a new sending domain on the account. Returns the full set of DNS records that must be published before email can send from this domain. Idempotent: calling this with a domain already registered on the current project returns the existing domain (200) instead of erroring, so re-runs from IaC tooling are safe.
27 28 29 30 |
# File 'lib/zyphr/api/domains_api.rb', line 27 def add_domain(add_domain_request, opts = {}) data, _status_code, _headers = add_domain_with_http_info(add_domain_request, opts) data end |
#add_domain_with_http_info(add_domain_request, opts = {}) ⇒ Array<(AddDomain200Response, Integer, Hash)>
Add a sending domain Register a new sending domain on the account. Returns the full set of DNS records that must be published before email can send from this domain. Idempotent: calling this with a domain already registered on the current project returns the existing domain (200) instead of erroring, so re-runs from IaC tooling are safe.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zyphr/api/domains_api.rb', line 37 def add_domain_with_http_info(add_domain_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.add_domain ...' end # verify the required parameter 'add_domain_request' is set if @api_client.config.client_side_validation && add_domain_request.nil? fail ArgumentError, "Missing the required parameter 'add_domain_request' when calling DomainsApi.add_domain" end # resource path local_var_path = '/domains' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(add_domain_request) # return_type return_type = opts[:debug_return_type] || 'AddDomain200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DomainsApi.add_domain", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#add_domain\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_domain(id, opts = {}) ⇒ DeleteDomainResponse
Remove a sending domain Remove a sending domain from the project. The domain is also detached from any SES identity that was provisioned for it. Returns 409 if the domain is still referenced by other resources (templates, scheduled sends, etc.) — those must be removed first.
95 96 97 98 |
# File 'lib/zyphr/api/domains_api.rb', line 95 def delete_domain(id, opts = {}) data, _status_code, _headers = delete_domain_with_http_info(id, opts) data end |
#delete_domain_with_http_info(id, opts = {}) ⇒ Array<(DeleteDomainResponse, Integer, Hash)>
Remove a sending domain Remove a sending domain from the project. The domain is also detached from any SES identity that was provisioned for it. Returns 409 if the domain is still referenced by other resources (templates, scheduled sends, etc.) — those must be removed first.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/zyphr/api/domains_api.rb', line 105 def delete_domain_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.delete_domain ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling DomainsApi.delete_domain" end # resource path local_var_path = '/domains/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DeleteDomainResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DomainsApi.delete_domain", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#delete_domain\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_domain(id, opts = {}) ⇒ GetDomain200Response
Get a sending domain Retrieve a single sending domain by ID, including DNS records and verification counters.
158 159 160 161 |
# File 'lib/zyphr/api/domains_api.rb', line 158 def get_domain(id, opts = {}) data, _status_code, _headers = get_domain_with_http_info(id, opts) data end |
#get_domain_verification_status(id, opts = {}) ⇒ VerificationStatusResponse
Get domain verification status Returns the current verification status with per-record ‘verified` flags and aggregate counters. Useful when polling for terminal status from an AI agent (the recommended pattern is to subscribe to the `domain.verified` webhook event instead — see sc-5444).
221 222 223 224 |
# File 'lib/zyphr/api/domains_api.rb', line 221 def get_domain_verification_status(id, opts = {}) data, _status_code, _headers = get_domain_verification_status_with_http_info(id, opts) data end |
#get_domain_verification_status_with_http_info(id, opts = {}) ⇒ Array<(VerificationStatusResponse, Integer, Hash)>
Get domain verification status Returns the current verification status with per-record `verified` flags and aggregate counters. Useful when polling for terminal status from an AI agent (the recommended pattern is to subscribe to the `domain.verified` webhook event instead — see sc-5444).
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/zyphr/api/domains_api.rb', line 231 def get_domain_verification_status_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.get_domain_verification_status ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling DomainsApi.get_domain_verification_status" end # resource path local_var_path = '/domains/{id}/verification-status'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VerificationStatusResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DomainsApi.get_domain_verification_status", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#get_domain_verification_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_domain_with_http_info(id, opts = {}) ⇒ Array<(GetDomain200Response, Integer, Hash)>
Get a sending domain Retrieve a single sending domain by ID, including DNS records and verification counters.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/zyphr/api/domains_api.rb', line 168 def get_domain_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.get_domain ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling DomainsApi.get_domain" end # resource path local_var_path = '/domains/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetDomain200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DomainsApi.get_domain", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#get_domain\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_domains(opts = {}) ⇒ DomainListResponse
List sending domains List sending domains on the current project, with verification status and DNS records.
283 284 285 286 |
# File 'lib/zyphr/api/domains_api.rb', line 283 def list_domains(opts = {}) data, _status_code, _headers = list_domains_with_http_info(opts) data end |
#list_domains_with_http_info(opts = {}) ⇒ Array<(DomainListResponse, Integer, Hash)>
List sending domains List sending domains on the current project, with verification status and DNS records.
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/zyphr/api/domains_api.rb', line 292 def list_domains_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.list_domains ...' end # resource path local_var_path = '/domains' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DomainsApi.list_domains", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#list_domains\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#verify_domain(id, opts = {}) ⇒ VerifyDomainResponse
Trigger domain verification Queue an asynchronous DNS verification check. Returns immediately with a ‘job_id`. Poll `GET /v1/domains/id/verification-status` (or the higher-level `GET /v1/domains/id`) for the result, or subscribe to the `domain.verified` webhook event when sc-5444 ships. Returns 409 if a verification is already in progress for this domain (within the last 2 minutes).
341 342 343 344 |
# File 'lib/zyphr/api/domains_api.rb', line 341 def verify_domain(id, opts = {}) data, _status_code, _headers = verify_domain_with_http_info(id, opts) data end |
#verify_domain_with_http_info(id, opts = {}) ⇒ Array<(VerifyDomainResponse, Integer, Hash)>
Trigger domain verification Queue an asynchronous DNS verification check. Returns immediately with a `job_id`. Poll `GET /v1/domains/id/verification-status` (or the higher-level `GET /v1/domains/id`) for the result, or subscribe to the `domain.verified` webhook event when sc-5444 ships. Returns 409 if a verification is already in progress for this domain (within the last 2 minutes).
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/zyphr/api/domains_api.rb', line 351 def verify_domain_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.verify_domain ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling DomainsApi.verify_domain" end # resource path local_var_path = '/domains/{id}/verify'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VerifyDomainResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DomainsApi.verify_domain", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#verify_domain\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |