Class: Zyphr::EmailMessage
- Inherits:
-
Object
- Object
- Zyphr::EmailMessage
- Defined in:
- lib/zyphr/models/email_message.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#bounced_at ⇒ Object
Returns the value of attribute bounced_at.
-
#clicked_at ⇒ Object
Returns the value of attribute clicked_at.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#delivered_at ⇒ Object
Returns the value of attribute delivered_at.
-
#from ⇒ Object
Returns the value of attribute from.
-
#id ⇒ Object
Returns the value of attribute id.
-
#opened_at ⇒ Object
Returns the value of attribute opened_at.
-
#queued_at ⇒ Object
Returns the value of attribute queued_at.
-
#sent_at ⇒ Object
Returns the value of attribute sent_at.
-
#status ⇒ Object
Returns the value of attribute status.
-
#subject ⇒ Object
Returns the value of attribute subject.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#to ⇒ Object
Returns the value of attribute to.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmailMessage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EmailMessage
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/zyphr/models/email_message.rb', line 127 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zyphr::EmailMessage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zyphr::EmailMessage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'from') self.from = attributes[:'from'] end if attributes.key?(:'to') self.to = attributes[:'to'] end if attributes.key?(:'subject') self.subject = attributes[:'subject'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'queued_at') self.queued_at = attributes[:'queued_at'] end if attributes.key?(:'sent_at') self.sent_at = attributes[:'sent_at'] end if attributes.key?(:'delivered_at') self.delivered_at = attributes[:'delivered_at'] end if attributes.key?(:'bounced_at') self.bounced_at = attributes[:'bounced_at'] end if attributes.key?(:'opened_at') self.opened_at = attributes[:'opened_at'] end if attributes.key?(:'clicked_at') self.clicked_at = attributes[:'clicked_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#bounced_at ⇒ Object
Returns the value of attribute bounced_at.
36 37 38 |
# File 'lib/zyphr/models/email_message.rb', line 36 def bounced_at @bounced_at end |
#clicked_at ⇒ Object
Returns the value of attribute clicked_at.
40 41 42 |
# File 'lib/zyphr/models/email_message.rb', line 40 def clicked_at @clicked_at end |
#created_at ⇒ Object
Returns the value of attribute created_at.
42 43 44 |
# File 'lib/zyphr/models/email_message.rb', line 42 def created_at @created_at end |
#delivered_at ⇒ Object
Returns the value of attribute delivered_at.
34 35 36 |
# File 'lib/zyphr/models/email_message.rb', line 34 def delivered_at @delivered_at end |
#from ⇒ Object
Returns the value of attribute from.
20 21 22 |
# File 'lib/zyphr/models/email_message.rb', line 20 def from @from end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zyphr/models/email_message.rb', line 18 def id @id end |
#opened_at ⇒ Object
Returns the value of attribute opened_at.
38 39 40 |
# File 'lib/zyphr/models/email_message.rb', line 38 def opened_at @opened_at end |
#queued_at ⇒ Object
Returns the value of attribute queued_at.
30 31 32 |
# File 'lib/zyphr/models/email_message.rb', line 30 def queued_at @queued_at end |
#sent_at ⇒ Object
Returns the value of attribute sent_at.
32 33 34 |
# File 'lib/zyphr/models/email_message.rb', line 32 def sent_at @sent_at end |
#status ⇒ Object
Returns the value of attribute status.
26 27 28 |
# File 'lib/zyphr/models/email_message.rb', line 26 def status @status end |
#subject ⇒ Object
Returns the value of attribute subject.
24 25 26 |
# File 'lib/zyphr/models/email_message.rb', line 24 def subject @subject end |
#tags ⇒ Object
Returns the value of attribute tags.
28 29 30 |
# File 'lib/zyphr/models/email_message.rb', line 28 def @tags end |
#to ⇒ Object
Returns the value of attribute to.
22 23 24 |
# File 'lib/zyphr/models/email_message.rb', line 22 def to @to end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/zyphr/models/email_message.rb', line 282 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Zyphr.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
86 87 88 |
# File 'lib/zyphr/models/email_message.rb', line 86 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
91 92 93 |
# File 'lib/zyphr/models/email_message.rb', line 91 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/zyphr/models/email_message.rb', line 67 def self.attribute_map { :'id' => :'id', :'from' => :'from', :'to' => :'to', :'subject' => :'subject', :'status' => :'status', :'tags' => :'tags', :'queued_at' => :'queued_at', :'sent_at' => :'sent_at', :'delivered_at' => :'delivered_at', :'bounced_at' => :'bounced_at', :'opened_at' => :'opened_at', :'clicked_at' => :'clicked_at', :'created_at' => :'created_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/zyphr/models/email_message.rb', line 258 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
115 116 117 118 119 120 121 122 123 |
# File 'lib/zyphr/models/email_message.rb', line 115 def self.openapi_nullable Set.new([ :'sent_at', :'delivered_at', :'bounced_at', :'opened_at', :'clicked_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/zyphr/models/email_message.rb', line 96 def self.openapi_types { :'id' => :'String', :'from' => :'EmailAddress', :'to' => :'EmailAddress', :'subject' => :'String', :'status' => :'String', :'tags' => :'Array<String>', :'queued_at' => :'Time', :'sent_at' => :'Time', :'delivered_at' => :'Time', :'bounced_at' => :'Time', :'opened_at' => :'Time', :'clicked_at' => :'Time', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/zyphr/models/email_message.rb', line 225 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && from == o.from && to == o.to && subject == o.subject && status == o.status && == o. && queued_at == o.queued_at && sent_at == o.sent_at && delivered_at == o.delivered_at && bounced_at == o.bounced_at && opened_at == o.opened_at && clicked_at == o.clicked_at && created_at == o.created_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/zyphr/models/email_message.rb', line 353 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
245 246 247 |
# File 'lib/zyphr/models/email_message.rb', line 245 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
251 252 253 |
# File 'lib/zyphr/models/email_message.rb', line 251 def hash [id, from, to, subject, status, , queued_at, sent_at, delivered_at, bounced_at, opened_at, clicked_at, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
198 199 200 201 202 |
# File 'lib/zyphr/models/email_message.rb', line 198 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
329 330 331 |
# File 'lib/zyphr/models/email_message.rb', line 329 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/zyphr/models/email_message.rb', line 335 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
323 324 325 |
# File 'lib/zyphr/models/email_message.rb', line 323 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
206 207 208 209 210 211 |
# File 'lib/zyphr/models/email_message.rb', line 206 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["pending", "queued", "sent", "delivered", "failed", "bounced", "rejected"]) return false unless status_validator.valid?(@status) true end |