Class: Zyphr::SendPushRequest
- Inherits:
-
Object
- Object
- Zyphr::SendPushRequest
- Defined in:
- lib/zyphr/models/send_push_request.rb
Instance Attribute Summary collapse
-
#action_buttons ⇒ Object
Interactive notification buttons (max 3).
-
#badge ⇒ Object
Badge count (iOS).
-
#body ⇒ Object
Push notification body text.
-
#category ⇒ Object
Notification category for preference checking.
-
#collapse_key ⇒ Object
Replace previous notification with same key.
-
#content_available ⇒ Object
Silent/background push notification.
-
#data ⇒ Object
Custom data payload.
-
#delay ⇒ Object
Delay in seconds before sending.
-
#device_id ⇒ Object
Send to a specific device.
-
#force ⇒ Object
Skip subscriber preference checks.
-
#image_url ⇒ Object
Image URL for rich notifications.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#send_at ⇒ Object
Schedule for future delivery (ISO 8601).
-
#sound ⇒ Object
Notification sound.
-
#subscriber_external_id ⇒ Object
Subscriber external ID for preference checking.
-
#subscriber_id ⇒ Object
Subscriber ID for preference checking.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#title ⇒ Object
Push notification title.
-
#user_id ⇒ Object
Send to all devices for a user.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SendPushRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ SendPushRequest
Initializes the object
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/zyphr/models/send_push_request.rb', line 141 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zyphr::SendPushRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zyphr::SendPushRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'device_id') self.device_id = attributes[:'device_id'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'data') if (value = attributes[:'data']).is_a?(Hash) self.data = value end end if attributes.key?(:'badge') self.badge = attributes[:'badge'] end if attributes.key?(:'sound') self.sound = attributes[:'sound'] end if attributes.key?(:'image_url') self.image_url = attributes[:'image_url'] end if attributes.key?(:'content_available') self.content_available = attributes[:'content_available'] end if attributes.key?(:'action_buttons') if (value = attributes[:'action_buttons']).is_a?(Array) self. = value end end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'collapse_key') self.collapse_key = attributes[:'collapse_key'] end if attributes.key?(:'subscriber_id') self.subscriber_id = attributes[:'subscriber_id'] end if attributes.key?(:'subscriber_external_id') self.subscriber_external_id = attributes[:'subscriber_external_id'] end if attributes.key?(:'category') self.category = attributes[:'category'] end if attributes.key?(:'force') self.force = attributes[:'force'] end if attributes.key?(:'send_at') self.send_at = attributes[:'send_at'] end if attributes.key?(:'delay') self.delay = attributes[:'delay'] end end |
Instance Attribute Details
#action_buttons ⇒ Object
Interactive notification buttons (max 3)
46 47 48 |
# File 'lib/zyphr/models/send_push_request.rb', line 46 def @action_buttons end |
#badge ⇒ Object
Badge count (iOS)
34 35 36 |
# File 'lib/zyphr/models/send_push_request.rb', line 34 def badge @badge end |
#body ⇒ Object
Push notification body text
28 29 30 |
# File 'lib/zyphr/models/send_push_request.rb', line 28 def body @body end |
#category ⇒ Object
Notification category for preference checking
62 63 64 |
# File 'lib/zyphr/models/send_push_request.rb', line 62 def category @category end |
#collapse_key ⇒ Object
Replace previous notification with same key
53 54 55 |
# File 'lib/zyphr/models/send_push_request.rb', line 53 def collapse_key @collapse_key end |
#content_available ⇒ Object
Silent/background push notification
43 44 45 |
# File 'lib/zyphr/models/send_push_request.rb', line 43 def content_available @content_available end |
#data ⇒ Object
Custom data payload
31 32 33 |
# File 'lib/zyphr/models/send_push_request.rb', line 31 def data @data end |
#delay ⇒ Object
Delay in seconds before sending
71 72 73 |
# File 'lib/zyphr/models/send_push_request.rb', line 71 def delay @delay end |
#device_id ⇒ Object
Send to a specific device
22 23 24 |
# File 'lib/zyphr/models/send_push_request.rb', line 22 def device_id @device_id end |
#force ⇒ Object
Skip subscriber preference checks
65 66 67 |
# File 'lib/zyphr/models/send_push_request.rb', line 65 def force @force end |
#image_url ⇒ Object
Image URL for rich notifications
40 41 42 |
# File 'lib/zyphr/models/send_push_request.rb', line 40 def image_url @image_url end |
#metadata ⇒ Object
Returns the value of attribute metadata.
50 51 52 |
# File 'lib/zyphr/models/send_push_request.rb', line 50 def @metadata end |
#send_at ⇒ Object
Schedule for future delivery (ISO 8601)
68 69 70 |
# File 'lib/zyphr/models/send_push_request.rb', line 68 def send_at @send_at end |
#sound ⇒ Object
Notification sound
37 38 39 |
# File 'lib/zyphr/models/send_push_request.rb', line 37 def sound @sound end |
#subscriber_external_id ⇒ Object
Subscriber external ID for preference checking
59 60 61 |
# File 'lib/zyphr/models/send_push_request.rb', line 59 def subscriber_external_id @subscriber_external_id end |
#subscriber_id ⇒ Object
Subscriber ID for preference checking
56 57 58 |
# File 'lib/zyphr/models/send_push_request.rb', line 56 def subscriber_id @subscriber_id end |
#tags ⇒ Object
Returns the value of attribute tags.
48 49 50 |
# File 'lib/zyphr/models/send_push_request.rb', line 48 def @tags end |
#title ⇒ Object
Push notification title
25 26 27 |
# File 'lib/zyphr/models/send_push_request.rb', line 25 def title @title end |
#user_id ⇒ Object
Send to all devices for a user
19 20 21 |
# File 'lib/zyphr/models/send_push_request.rb', line 19 def user_id @user_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 |
# File 'lib/zyphr/models/send_push_request.rb', line 453 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Zyphr.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
99 100 101 |
# File 'lib/zyphr/models/send_push_request.rb', line 99 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
104 105 106 |
# File 'lib/zyphr/models/send_push_request.rb', line 104 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/zyphr/models/send_push_request.rb', line 74 def self.attribute_map { :'user_id' => :'user_id', :'device_id' => :'device_id', :'title' => :'title', :'body' => :'body', :'data' => :'data', :'badge' => :'badge', :'sound' => :'sound', :'image_url' => :'image_url', :'content_available' => :'content_available', :'action_buttons' => :'action_buttons', :'tags' => :'tags', :'metadata' => :'metadata', :'collapse_key' => :'collapse_key', :'subscriber_id' => :'subscriber_id', :'subscriber_external_id' => :'subscriber_external_id', :'category' => :'category', :'force' => :'force', :'send_at' => :'send_at', :'delay' => :'delay' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/zyphr/models/send_push_request.rb', line 429 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
134 135 136 137 |
# File 'lib/zyphr/models/send_push_request.rb', line 134 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/zyphr/models/send_push_request.rb', line 109 def self.openapi_types { :'user_id' => :'String', :'device_id' => :'String', :'title' => :'String', :'body' => :'String', :'data' => :'Hash<String, Object>', :'badge' => :'Integer', :'sound' => :'String', :'image_url' => :'String', :'content_available' => :'Boolean', :'action_buttons' => :'Array<SendPushRequestActionButtonsInner>', :'tags' => :'Array<String>', :'metadata' => :'Hash<String, Object>', :'collapse_key' => :'String', :'subscriber_id' => :'String', :'subscriber_external_id' => :'String', :'category' => :'String', :'force' => :'Boolean', :'send_at' => :'Time', :'delay' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/zyphr/models/send_push_request.rb', line 390 def ==(o) return true if self.equal?(o) self.class == o.class && user_id == o.user_id && device_id == o.device_id && title == o.title && body == o.body && data == o.data && badge == o.badge && sound == o.sound && image_url == o.image_url && content_available == o.content_available && == o. && == o. && == o. && collapse_key == o.collapse_key && subscriber_id == o.subscriber_id && subscriber_external_id == o.subscriber_external_id && category == o.category && force == o.force && send_at == o.send_at && delay == o.delay end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
524 525 526 527 528 529 530 531 532 533 534 535 536 |
# File 'lib/zyphr/models/send_push_request.rb', line 524 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
416 417 418 |
# File 'lib/zyphr/models/send_push_request.rb', line 416 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
422 423 424 |
# File 'lib/zyphr/models/send_push_request.rb', line 422 def hash [user_id, device_id, title, body, data, badge, sound, image_url, content_available, , , , collapse_key, subscriber_id, subscriber_external_id, category, force, send_at, delay].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/zyphr/models/send_push_request.rb', line 242 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@title.nil? && @title.to_s.length > 255 invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 255.') end if !@body.nil? && @body.to_s.length > 4096 invalid_properties.push('invalid value for "body", the character length must be smaller than or equal to 4096.') end if !@badge.nil? && @badge < 0 invalid_properties.push('invalid value for "badge", must be greater than or equal to 0.') end if !@sound.nil? && @sound.to_s.length > 255 invalid_properties.push('invalid value for "sound", the character length must be smaller than or equal to 255.') end if !@action_buttons.nil? && @action_buttons.length > 3 invalid_properties.push('invalid value for "action_buttons", number of items must be less than or equal to 3.') end if !@tags.nil? && @tags.length > 10 invalid_properties.push('invalid value for "tags", number of items must be less than or equal to 10.') end if !@delay.nil? && @delay < 0 invalid_properties.push('invalid value for "delay", must be greater than or equal to 0.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
500 501 502 |
# File 'lib/zyphr/models/send_push_request.rb', line 500 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/zyphr/models/send_push_request.rb', line 506 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
494 495 496 |
# File 'lib/zyphr/models/send_push_request.rb', line 494 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/zyphr/models/send_push_request.rb', line 278 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@title.nil? && @title.to_s.length > 255 return false if !@body.nil? && @body.to_s.length > 4096 return false if !@badge.nil? && @badge < 0 return false if !@sound.nil? && @sound.to_s.length > 255 return false if !@action_buttons.nil? && @action_buttons.length > 3 return false if !@tags.nil? && @tags.length > 10 return false if !@delay.nil? && @delay < 0 true end |