Class: Zyphr::SmsMessageDetail
- Inherits:
-
Object
- Object
- Zyphr::SmsMessageDetail
- Defined in:
- lib/zyphr/models/sms_message_detail.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#body ⇒ Object
Returns the value of attribute body.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#delivered_at ⇒ Object
Returns the value of attribute delivered_at.
-
#failed_at ⇒ Object
Returns the value of attribute failed_at.
-
#from ⇒ Object
Returns the value of attribute from.
-
#from_number ⇒ Object
Returns the value of attribute from_number.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_test ⇒ Object
Returns the value of attribute is_test.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#provider_message_id ⇒ Object
Returns the value of attribute provider_message_id.
-
#queued_at ⇒ Object
Returns the value of attribute queued_at.
-
#scheduled_for ⇒ Object
Returns the value of attribute scheduled_for.
-
#segments ⇒ Object
Number of SMS segments.
-
#sent_at ⇒ Object
Returns the value of attribute sent_at.
-
#status ⇒ Object
Returns the value of attribute status.
-
#status_reason ⇒ Object
Returns the value of attribute status_reason.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#to_number ⇒ Object
Returns the value of attribute to_number.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SmsMessageDetail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ SmsMessageDetail
Initializes the object
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 157 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zyphr::SmsMessageDetail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zyphr::SmsMessageDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'from_number') self.from_number = attributes[:'from_number'] end if attributes.key?(:'to_number') self.to_number = attributes[:'to_number'] end if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'segments') self.segments = attributes[:'segments'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'sent_at') self.sent_at = attributes[:'sent_at'] end if attributes.key?(:'from') self.from = attributes[:'from'] end if attributes.key?(:'status_reason') self.status_reason = attributes[:'status_reason'] end if attributes.key?(:'provider_message_id') self. = attributes[:'provider_message_id'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'scheduled_for') self.scheduled_for = attributes[:'scheduled_for'] end if attributes.key?(:'queued_at') self.queued_at = attributes[:'queued_at'] end if attributes.key?(:'delivered_at') self.delivered_at = attributes[:'delivered_at'] end if attributes.key?(:'failed_at') self.failed_at = attributes[:'failed_at'] end if attributes.key?(:'is_test') self.is_test = attributes[:'is_test'] end end |
Instance Attribute Details
#body ⇒ Object
Returns the value of attribute body.
24 25 26 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 24 def body @body end |
#created_at ⇒ Object
Returns the value of attribute created_at.
31 32 33 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 31 def created_at @created_at end |
#delivered_at ⇒ Object
Returns the value of attribute delivered_at.
49 50 51 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 49 def delivered_at @delivered_at end |
#failed_at ⇒ Object
Returns the value of attribute failed_at.
51 52 53 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 51 def failed_at @failed_at end |
#from ⇒ Object
Returns the value of attribute from.
35 36 37 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 35 def from @from end |
#from_number ⇒ Object
Returns the value of attribute from_number.
20 21 22 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 20 def from_number @from_number end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 18 def id @id end |
#is_test ⇒ Object
Returns the value of attribute is_test.
53 54 55 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 53 def is_test @is_test end |
#metadata ⇒ Object
Returns the value of attribute metadata.
43 44 45 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 43 def @metadata end |
#provider_message_id ⇒ Object
Returns the value of attribute provider_message_id.
39 40 41 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 39 def @provider_message_id end |
#queued_at ⇒ Object
Returns the value of attribute queued_at.
47 48 49 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 47 def queued_at @queued_at end |
#scheduled_for ⇒ Object
Returns the value of attribute scheduled_for.
45 46 47 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 45 def scheduled_for @scheduled_for end |
#segments ⇒ Object
Number of SMS segments
29 30 31 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 29 def segments @segments end |
#sent_at ⇒ Object
Returns the value of attribute sent_at.
33 34 35 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 33 def sent_at @sent_at end |
#status ⇒ Object
Returns the value of attribute status.
26 27 28 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 26 def status @status end |
#status_reason ⇒ Object
Returns the value of attribute status_reason.
37 38 39 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 37 def status_reason @status_reason end |
#tags ⇒ Object
Returns the value of attribute tags.
41 42 43 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 41 def @tags end |
#to_number ⇒ Object
Returns the value of attribute to_number.
22 23 24 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 22 def to_number @to_number end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 339 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Zyphr.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
102 103 104 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 102 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
107 108 109 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 107 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 78 def self.attribute_map { :'id' => :'id', :'from_number' => :'from_number', :'to_number' => :'to_number', :'body' => :'body', :'status' => :'status', :'segments' => :'segments', :'created_at' => :'created_at', :'sent_at' => :'sent_at', :'from' => :'from', :'status_reason' => :'status_reason', :'provider_message_id' => :'provider_message_id', :'tags' => :'tags', :'metadata' => :'metadata', :'scheduled_for' => :'scheduled_for', :'queued_at' => :'queued_at', :'delivered_at' => :'delivered_at', :'failed_at' => :'failed_at', :'is_test' => :'is_test' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 315 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
149 150 151 152 153 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 149 def self.openapi_all_of [ :'SmsMessage' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 136 def self.openapi_nullable Set.new([ :'sent_at', :'status_reason', :'provider_message_id', :'scheduled_for', :'queued_at', :'delivered_at', :'failed_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 112 def self.openapi_types { :'id' => :'String', :'from_number' => :'String', :'to_number' => :'String', :'body' => :'String', :'status' => :'String', :'segments' => :'Integer', :'created_at' => :'Time', :'sent_at' => :'Time', :'from' => :'String', :'status_reason' => :'String', :'provider_message_id' => :'String', :'tags' => :'Array<String>', :'metadata' => :'Hash<String, Object>', :'scheduled_for' => :'Time', :'queued_at' => :'Time', :'delivered_at' => :'Time', :'failed_at' => :'Time', :'is_test' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 277 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && from_number == o.from_number && to_number == o.to_number && body == o.body && status == o.status && segments == o.segments && created_at == o.created_at && sent_at == o.sent_at && from == o.from && status_reason == o.status_reason && == o. && == o. && == o. && scheduled_for == o.scheduled_for && queued_at == o.queued_at && delivered_at == o.delivered_at && failed_at == o.failed_at && is_test == o.is_test end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 410 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
302 303 304 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 302 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
308 309 310 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 308 def hash [id, from_number, to_number, body, status, segments, created_at, sent_at, from, status_reason, , , , scheduled_for, queued_at, delivered_at, failed_at, is_test].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
250 251 252 253 254 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 250 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
386 387 388 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 386 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 392 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
380 381 382 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 380 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
258 259 260 261 262 263 |
# File 'lib/zyphr/models/sms_message_detail.rb', line 258 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["pending", "queued", "sent", "delivered", "failed"]) return false unless status_validator.valid?(@status) true end |