Class: Zyphr::UtilityApi
- Inherits:
-
Object
- Object
- Zyphr::UtilityApi
- Defined in:
- lib/zyphr/api/utility_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_password_requirements(opts = {}) ⇒ PasswordRequirementsResponse
Get password requirements Get password requirements for the application.
-
#get_password_requirements_with_http_info(opts = {}) ⇒ Array<(PasswordRequirementsResponse, Integer, Hash)>
Get password requirements Get password requirements for the application.
-
#initialize(api_client = ApiClient.default) ⇒ UtilityApi
constructor
A new instance of UtilityApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ UtilityApi
Returns a new instance of UtilityApi.
19 20 21 |
# File 'lib/zyphr/api/utility_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zyphr/api/utility_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_password_requirements(opts = {}) ⇒ PasswordRequirementsResponse
Get password requirements Get password requirements for the application. Useful for client-side validation before registration.
26 27 28 29 |
# File 'lib/zyphr/api/utility_api.rb', line 26 def get_password_requirements(opts = {}) data, _status_code, _headers = get_password_requirements_with_http_info(opts) data end |
#get_password_requirements_with_http_info(opts = {}) ⇒ Array<(PasswordRequirementsResponse, Integer, Hash)>
Get password requirements Get password requirements for the application. Useful for client-side validation before registration.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/zyphr/api/utility_api.rb', line 35 def get_password_requirements_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UtilityApi.get_password_requirements ...' end # resource path local_var_path = '/auth/password-requirements' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PasswordRequirementsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApplicationPublicKey'] = opts.merge( :operation => :"UtilityApi.get_password_requirements", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UtilityApi#get_password_requirements\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |