Class: Zyphr::WaaSEndpointsApi
- Inherits:
-
Object
- Object
- Zyphr::WaaSEndpointsApi
- Defined in:
- lib/zyphr/api/waa_s_endpoints_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#close_waa_s_endpoint_circuit(app_id, endpoint_id, opts = {}) ⇒ nil
Force-close circuit breaker Force the circuit breaker to close, resuming deliveries to the endpoint.
-
#close_waa_s_endpoint_circuit_with_http_info(app_id, endpoint_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Force-close circuit breaker Force the circuit breaker to close, resuming deliveries to the endpoint.
-
#create_waa_s_endpoint(app_id, create_waa_s_endpoint_request, opts = {}) ⇒ CreateWaaSEndpoint201Response
Create a tenant endpoint Create a webhook endpoint for a specific tenant.
-
#create_waa_s_endpoint_with_http_info(app_id, create_waa_s_endpoint_request, opts = {}) ⇒ Array<(CreateWaaSEndpoint201Response, Integer, Hash)>
Create a tenant endpoint Create a webhook endpoint for a specific tenant.
-
#delete_waa_s_endpoint(app_id, endpoint_id, opts = {}) ⇒ nil
Delete an endpoint Delete a tenant endpoint.
-
#delete_waa_s_endpoint_with_http_info(app_id, endpoint_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an endpoint Delete a tenant endpoint.
-
#get_waa_s_endpoint(app_id, endpoint_id, opts = {}) ⇒ GetWaaSEndpoint200Response
Get an endpoint.
-
#get_waa_s_endpoint_circuit(app_id, endpoint_id, opts = {}) ⇒ nil
Get circuit breaker state Get the circuit breaker state for an endpoint (closed, open, or half-open).
-
#get_waa_s_endpoint_circuit_with_http_info(app_id, endpoint_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get circuit breaker state Get the circuit breaker state for an endpoint (closed, open, or half-open).
-
#get_waa_s_endpoint_metrics(app_id, endpoint_id, opts = {}) ⇒ nil
Get endpoint metrics Get delivery success rate, latency, and health metrics for an endpoint.
-
#get_waa_s_endpoint_metrics_with_http_info(app_id, endpoint_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get endpoint metrics Get delivery success rate, latency, and health metrics for an endpoint.
-
#get_waa_s_endpoint_with_http_info(app_id, endpoint_id, opts = {}) ⇒ Array<(GetWaaSEndpoint200Response, Integer, Hash)>
Get an endpoint.
-
#initialize(api_client = ApiClient.default) ⇒ WaaSEndpointsApi
constructor
A new instance of WaaSEndpointsApi.
-
#list_waa_s_endpoints(app_id, opts = {}) ⇒ ListWaaSEndpoints200Response
List tenant endpoints List all endpoints for a WaaS application.
-
#list_waa_s_endpoints_with_http_info(app_id, opts = {}) ⇒ Array<(ListWaaSEndpoints200Response, Integer, Hash)>
List tenant endpoints List all endpoints for a WaaS application.
-
#rotate_waa_s_endpoint_secret(app_id, endpoint_id, opts = {}) ⇒ nil
Rotate endpoint secret Rotate the signing secret for an endpoint.
-
#rotate_waa_s_endpoint_secret_with_http_info(app_id, endpoint_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Rotate endpoint secret Rotate the signing secret for an endpoint.
-
#update_waa_s_endpoint(app_id, endpoint_id, update_waa_s_endpoint_request, opts = {}) ⇒ nil
Update an endpoint.
-
#update_waa_s_endpoint_with_http_info(app_id, endpoint_id, update_waa_s_endpoint_request, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update an endpoint.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WaaSEndpointsApi
Returns a new instance of WaaSEndpointsApi.
19 20 21 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#close_waa_s_endpoint_circuit(app_id, endpoint_id, opts = {}) ⇒ nil
Force-close circuit breaker Force the circuit breaker to close, resuming deliveries to the endpoint.
28 29 30 31 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 28 def close_waa_s_endpoint_circuit(app_id, endpoint_id, opts = {}) close_waa_s_endpoint_circuit_with_http_info(app_id, endpoint_id, opts) nil end |
#close_waa_s_endpoint_circuit_with_http_info(app_id, endpoint_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Force-close circuit breaker Force the circuit breaker to close, resuming deliveries to the endpoint.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 39 def close_waa_s_endpoint_circuit_with_http_info(app_id, endpoint_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WaaSEndpointsApi.close_waa_s_endpoint_circuit ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling WaaSEndpointsApi.close_waa_s_endpoint_circuit" end # verify the required parameter 'endpoint_id' is set if @api_client.config.client_side_validation && endpoint_id.nil? fail ArgumentError, "Missing the required parameter 'endpoint_id' when calling WaaSEndpointsApi.close_waa_s_endpoint_circuit" end # resource path local_var_path = '/v1/waas/applications/{appId}/endpoints/{endpointId}/circuit/close'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)).sub('{' + 'endpointId' + '}', CGI.escape(endpoint_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WaaSEndpointsApi.close_waa_s_endpoint_circuit", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WaaSEndpointsApi#close_waa_s_endpoint_circuit\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_waa_s_endpoint(app_id, create_waa_s_endpoint_request, opts = {}) ⇒ CreateWaaSEndpoint201Response
Create a tenant endpoint Create a webhook endpoint for a specific tenant. The signing secret is returned only on creation.
95 96 97 98 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 95 def create_waa_s_endpoint(app_id, create_waa_s_endpoint_request, opts = {}) data, _status_code, _headers = create_waa_s_endpoint_with_http_info(app_id, create_waa_s_endpoint_request, opts) data end |
#create_waa_s_endpoint_with_http_info(app_id, create_waa_s_endpoint_request, opts = {}) ⇒ Array<(CreateWaaSEndpoint201Response, Integer, Hash)>
Create a tenant endpoint Create a webhook endpoint for a specific tenant. The signing secret is returned only on creation.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 106 def create_waa_s_endpoint_with_http_info(app_id, create_waa_s_endpoint_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WaaSEndpointsApi.create_waa_s_endpoint ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling WaaSEndpointsApi.create_waa_s_endpoint" end # verify the required parameter 'create_waa_s_endpoint_request' is set if @api_client.config.client_side_validation && create_waa_s_endpoint_request.nil? fail ArgumentError, "Missing the required parameter 'create_waa_s_endpoint_request' when calling WaaSEndpointsApi.create_waa_s_endpoint" end # resource path local_var_path = '/v1/waas/applications/{appId}/endpoints'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_waa_s_endpoint_request) # return_type return_type = opts[:debug_return_type] || 'CreateWaaSEndpoint201Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WaaSEndpointsApi.create_waa_s_endpoint", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WaaSEndpointsApi#create_waa_s_endpoint\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_waa_s_endpoint(app_id, endpoint_id, opts = {}) ⇒ nil
Delete an endpoint Delete a tenant endpoint. Stops all future deliveries and removes pending retries.
169 170 171 172 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 169 def delete_waa_s_endpoint(app_id, endpoint_id, opts = {}) delete_waa_s_endpoint_with_http_info(app_id, endpoint_id, opts) nil end |
#delete_waa_s_endpoint_with_http_info(app_id, endpoint_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an endpoint Delete a tenant endpoint. Stops all future deliveries and removes pending retries.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 180 def delete_waa_s_endpoint_with_http_info(app_id, endpoint_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WaaSEndpointsApi.delete_waa_s_endpoint ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling WaaSEndpointsApi.delete_waa_s_endpoint" end # verify the required parameter 'endpoint_id' is set if @api_client.config.client_side_validation && endpoint_id.nil? fail ArgumentError, "Missing the required parameter 'endpoint_id' when calling WaaSEndpointsApi.delete_waa_s_endpoint" end # resource path local_var_path = '/v1/waas/applications/{appId}/endpoints/{endpointId}'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)).sub('{' + 'endpointId' + '}', CGI.escape(endpoint_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WaaSEndpointsApi.delete_waa_s_endpoint", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WaaSEndpointsApi#delete_waa_s_endpoint\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_waa_s_endpoint(app_id, endpoint_id, opts = {}) ⇒ GetWaaSEndpoint200Response
Get an endpoint
235 236 237 238 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 235 def get_waa_s_endpoint(app_id, endpoint_id, opts = {}) data, _status_code, _headers = get_waa_s_endpoint_with_http_info(app_id, endpoint_id, opts) data end |
#get_waa_s_endpoint_circuit(app_id, endpoint_id, opts = {}) ⇒ nil
Get circuit breaker state Get the circuit breaker state for an endpoint (closed, open, or half-open).
303 304 305 306 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 303 def get_waa_s_endpoint_circuit(app_id, endpoint_id, opts = {}) get_waa_s_endpoint_circuit_with_http_info(app_id, endpoint_id, opts) nil end |
#get_waa_s_endpoint_circuit_with_http_info(app_id, endpoint_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get circuit breaker state Get the circuit breaker state for an endpoint (closed, open, or half-open).
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 314 def get_waa_s_endpoint_circuit_with_http_info(app_id, endpoint_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WaaSEndpointsApi.get_waa_s_endpoint_circuit ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling WaaSEndpointsApi.get_waa_s_endpoint_circuit" end # verify the required parameter 'endpoint_id' is set if @api_client.config.client_side_validation && endpoint_id.nil? fail ArgumentError, "Missing the required parameter 'endpoint_id' when calling WaaSEndpointsApi.get_waa_s_endpoint_circuit" end # resource path local_var_path = '/v1/waas/applications/{appId}/endpoints/{endpointId}/circuit'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)).sub('{' + 'endpointId' + '}', CGI.escape(endpoint_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WaaSEndpointsApi.get_waa_s_endpoint_circuit", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WaaSEndpointsApi#get_waa_s_endpoint_circuit\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_waa_s_endpoint_metrics(app_id, endpoint_id, opts = {}) ⇒ nil
Get endpoint metrics Get delivery success rate, latency, and health metrics for an endpoint.
370 371 372 373 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 370 def get_waa_s_endpoint_metrics(app_id, endpoint_id, opts = {}) get_waa_s_endpoint_metrics_with_http_info(app_id, endpoint_id, opts) nil end |
#get_waa_s_endpoint_metrics_with_http_info(app_id, endpoint_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get endpoint metrics Get delivery success rate, latency, and health metrics for an endpoint.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 381 def get_waa_s_endpoint_metrics_with_http_info(app_id, endpoint_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WaaSEndpointsApi.get_waa_s_endpoint_metrics ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling WaaSEndpointsApi.get_waa_s_endpoint_metrics" end # verify the required parameter 'endpoint_id' is set if @api_client.config.client_side_validation && endpoint_id.nil? fail ArgumentError, "Missing the required parameter 'endpoint_id' when calling WaaSEndpointsApi.get_waa_s_endpoint_metrics" end # resource path local_var_path = '/v1/waas/applications/{appId}/endpoints/{endpointId}/metrics'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)).sub('{' + 'endpointId' + '}', CGI.escape(endpoint_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WaaSEndpointsApi.get_waa_s_endpoint_metrics", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WaaSEndpointsApi#get_waa_s_endpoint_metrics\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_waa_s_endpoint_with_http_info(app_id, endpoint_id, opts = {}) ⇒ Array<(GetWaaSEndpoint200Response, Integer, Hash)>
Get an endpoint
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 245 def get_waa_s_endpoint_with_http_info(app_id, endpoint_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WaaSEndpointsApi.get_waa_s_endpoint ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling WaaSEndpointsApi.get_waa_s_endpoint" end # verify the required parameter 'endpoint_id' is set if @api_client.config.client_side_validation && endpoint_id.nil? fail ArgumentError, "Missing the required parameter 'endpoint_id' when calling WaaSEndpointsApi.get_waa_s_endpoint" end # resource path local_var_path = '/v1/waas/applications/{appId}/endpoints/{endpointId}'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)).sub('{' + 'endpointId' + '}', CGI.escape(endpoint_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetWaaSEndpoint200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WaaSEndpointsApi.get_waa_s_endpoint", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WaaSEndpointsApi#get_waa_s_endpoint\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_waa_s_endpoints(app_id, opts = {}) ⇒ ListWaaSEndpoints200Response
List tenant endpoints List all endpoints for a WaaS application. Optionally filter by tenant ID or status.
440 441 442 443 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 440 def list_waa_s_endpoints(app_id, opts = {}) data, _status_code, _headers = list_waa_s_endpoints_with_http_info(app_id, opts) data end |
#list_waa_s_endpoints_with_http_info(app_id, opts = {}) ⇒ Array<(ListWaaSEndpoints200Response, Integer, Hash)>
List tenant endpoints List all endpoints for a WaaS application. Optionally filter by tenant ID or status.
454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 454 def list_waa_s_endpoints_with_http_info(app_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WaaSEndpointsApi.list_waa_s_endpoints ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling WaaSEndpointsApi.list_waa_s_endpoints" end allowable_values = ["active", "paused", "disabled"] if @api_client.config.client_side_validation && opts[:'status'] && !allowable_values.include?(opts[:'status']) fail ArgumentError, "invalid value for \"status\", must be one of #{allowable_values}" end # resource path local_var_path = '/v1/waas/applications/{appId}/endpoints'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'tenant_id'] = opts[:'tenant_id'] if !opts[:'tenant_id'].nil? query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListWaaSEndpoints200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WaaSEndpointsApi.list_waa_s_endpoints", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WaaSEndpointsApi#list_waa_s_endpoints\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rotate_waa_s_endpoint_secret(app_id, endpoint_id, opts = {}) ⇒ nil
Rotate endpoint secret Rotate the signing secret for an endpoint. During rotation, deliveries are signed with both old and new secrets.
516 517 518 519 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 516 def rotate_waa_s_endpoint_secret(app_id, endpoint_id, opts = {}) rotate_waa_s_endpoint_secret_with_http_info(app_id, endpoint_id, opts) nil end |
#rotate_waa_s_endpoint_secret_with_http_info(app_id, endpoint_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Rotate endpoint secret Rotate the signing secret for an endpoint. During rotation, deliveries are signed with both old and new secrets.
527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 527 def rotate_waa_s_endpoint_secret_with_http_info(app_id, endpoint_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WaaSEndpointsApi.rotate_waa_s_endpoint_secret ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling WaaSEndpointsApi.rotate_waa_s_endpoint_secret" end # verify the required parameter 'endpoint_id' is set if @api_client.config.client_side_validation && endpoint_id.nil? fail ArgumentError, "Missing the required parameter 'endpoint_id' when calling WaaSEndpointsApi.rotate_waa_s_endpoint_secret" end # resource path local_var_path = '/v1/waas/applications/{appId}/endpoints/{endpointId}/rotate-secret'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)).sub('{' + 'endpointId' + '}', CGI.escape(endpoint_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WaaSEndpointsApi.rotate_waa_s_endpoint_secret", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WaaSEndpointsApi#rotate_waa_s_endpoint_secret\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_waa_s_endpoint(app_id, endpoint_id, update_waa_s_endpoint_request, opts = {}) ⇒ nil
Update an endpoint
583 584 585 586 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 583 def update_waa_s_endpoint(app_id, endpoint_id, update_waa_s_endpoint_request, opts = {}) update_waa_s_endpoint_with_http_info(app_id, endpoint_id, update_waa_s_endpoint_request, opts) nil end |
#update_waa_s_endpoint_with_http_info(app_id, endpoint_id, update_waa_s_endpoint_request, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update an endpoint
594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 |
# File 'lib/zyphr/api/waa_s_endpoints_api.rb', line 594 def update_waa_s_endpoint_with_http_info(app_id, endpoint_id, update_waa_s_endpoint_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WaaSEndpointsApi.update_waa_s_endpoint ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling WaaSEndpointsApi.update_waa_s_endpoint" end # verify the required parameter 'endpoint_id' is set if @api_client.config.client_side_validation && endpoint_id.nil? fail ArgumentError, "Missing the required parameter 'endpoint_id' when calling WaaSEndpointsApi.update_waa_s_endpoint" end # verify the required parameter 'update_waa_s_endpoint_request' is set if @api_client.config.client_side_validation && update_waa_s_endpoint_request.nil? fail ArgumentError, "Missing the required parameter 'update_waa_s_endpoint_request' when calling WaaSEndpointsApi.update_waa_s_endpoint" end # resource path local_var_path = '/v1/waas/applications/{appId}/endpoints/{endpointId}'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)).sub('{' + 'endpointId' + '}', CGI.escape(endpoint_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_waa_s_endpoint_request) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WaaSEndpointsApi.update_waa_s_endpoint", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WaaSEndpointsApi#update_waa_s_endpoint\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |