Class: Zyphr::WebhookDelivery

Inherits:
Object
  • Object
show all
Defined in:
lib/zyphr/models/webhook_delivery.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WebhookDelivery

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/zyphr/models/webhook_delivery.rb', line 142

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zyphr::WebhookDelivery` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zyphr::WebhookDelivery`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'msg_id')
    self.msg_id = attributes[:'msg_id']
  end

  if attributes.key?(:'event_id')
    self.event_id = attributes[:'event_id']
  end

  if attributes.key?(:'event_type')
    self.event_type = attributes[:'event_type']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'attempts')
    self.attempts = attributes[:'attempts']
  end

  if attributes.key?(:'max_attempts')
    self.max_attempts = attributes[:'max_attempts']
  end

  if attributes.key?(:'next_attempt_at')
    self.next_attempt_at = attributes[:'next_attempt_at']
  end

  if attributes.key?(:'last_response_status')
    self.last_response_status = attributes[:'last_response_status']
  end

  if attributes.key?(:'latency_ms')
    self.latency_ms = attributes[:'latency_ms']
  end

  if attributes.key?(:'last_error')
    self.last_error = attributes[:'last_error']
  end

  if attributes.key?(:'first_attempted_at')
    self.first_attempted_at = attributes[:'first_attempted_at']
  end

  if attributes.key?(:'last_attempted_at')
    self.last_attempted_at = attributes[:'last_attempted_at']
  end

  if attributes.key?(:'completed_at')
    self.completed_at = attributes[:'completed_at']
  end

  if attributes.key?(:'delivery_region')
    self.delivery_region = attributes[:'delivery_region']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#attemptsObject

Returns the value of attribute attempts.



28
29
30
# File 'lib/zyphr/models/webhook_delivery.rb', line 28

def attempts
  @attempts
end

#completed_atObject

Returns the value of attribute completed_at.



44
45
46
# File 'lib/zyphr/models/webhook_delivery.rb', line 44

def completed_at
  @completed_at
end

#created_atObject

Returns the value of attribute created_at.



48
49
50
# File 'lib/zyphr/models/webhook_delivery.rb', line 48

def created_at
  @created_at
end

#delivery_regionObject

Returns the value of attribute delivery_region.



46
47
48
# File 'lib/zyphr/models/webhook_delivery.rb', line 46

def delivery_region
  @delivery_region
end

#event_idObject

Returns the value of attribute event_id.



22
23
24
# File 'lib/zyphr/models/webhook_delivery.rb', line 22

def event_id
  @event_id
end

#event_typeObject

Returns the value of attribute event_type.



24
25
26
# File 'lib/zyphr/models/webhook_delivery.rb', line 24

def event_type
  @event_type
end

#first_attempted_atObject

Returns the value of attribute first_attempted_at.



40
41
42
# File 'lib/zyphr/models/webhook_delivery.rb', line 40

def first_attempted_at
  @first_attempted_at
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zyphr/models/webhook_delivery.rb', line 18

def id
  @id
end

#last_attempted_atObject

Returns the value of attribute last_attempted_at.



42
43
44
# File 'lib/zyphr/models/webhook_delivery.rb', line 42

def last_attempted_at
  @last_attempted_at
end

#last_errorObject

Returns the value of attribute last_error.



38
39
40
# File 'lib/zyphr/models/webhook_delivery.rb', line 38

def last_error
  @last_error
end

#last_response_statusObject

Returns the value of attribute last_response_status.



34
35
36
# File 'lib/zyphr/models/webhook_delivery.rb', line 34

def last_response_status
  @last_response_status
end

#latency_msObject

Returns the value of attribute latency_ms.



36
37
38
# File 'lib/zyphr/models/webhook_delivery.rb', line 36

def latency_ms
  @latency_ms
end

#max_attemptsObject

Returns the value of attribute max_attempts.



30
31
32
# File 'lib/zyphr/models/webhook_delivery.rb', line 30

def max_attempts
  @max_attempts
end

#msg_idObject

Returns the value of attribute msg_id.



20
21
22
# File 'lib/zyphr/models/webhook_delivery.rb', line 20

def msg_id
  @msg_id
end

#next_attempt_atObject

Returns the value of attribute next_attempt_at.



32
33
34
# File 'lib/zyphr/models/webhook_delivery.rb', line 32

def next_attempt_at
  @next_attempt_at
end

#statusObject

Returns the value of attribute status.



26
27
28
# File 'lib/zyphr/models/webhook_delivery.rb', line 26

def status
  @status
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/zyphr/models/webhook_delivery.rb', line 310

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Zyphr.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/zyphr/models/webhook_delivery.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/zyphr/models/webhook_delivery.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/zyphr/models/webhook_delivery.rb', line 73

def self.attribute_map
  {
    :'id' => :'id',
    :'msg_id' => :'msg_id',
    :'event_id' => :'event_id',
    :'event_type' => :'event_type',
    :'status' => :'status',
    :'attempts' => :'attempts',
    :'max_attempts' => :'max_attempts',
    :'next_attempt_at' => :'next_attempt_at',
    :'last_response_status' => :'last_response_status',
    :'latency_ms' => :'latency_ms',
    :'last_error' => :'last_error',
    :'first_attempted_at' => :'first_attempted_at',
    :'last_attempted_at' => :'last_attempted_at',
    :'completed_at' => :'completed_at',
    :'delivery_region' => :'delivery_region',
    :'created_at' => :'created_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/zyphr/models/webhook_delivery.rb', line 286

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/zyphr/models/webhook_delivery.rb', line 127

def self.openapi_nullable
  Set.new([
    :'next_attempt_at',
    :'last_response_status',
    :'latency_ms',
    :'last_error',
    :'first_attempted_at',
    :'last_attempted_at',
    :'completed_at',
    :'delivery_region',
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/zyphr/models/webhook_delivery.rb', line 105

def self.openapi_types
  {
    :'id' => :'String',
    :'msg_id' => :'String',
    :'event_id' => :'String',
    :'event_type' => :'String',
    :'status' => :'String',
    :'attempts' => :'Integer',
    :'max_attempts' => :'Integer',
    :'next_attempt_at' => :'Time',
    :'last_response_status' => :'Integer',
    :'latency_ms' => :'Integer',
    :'last_error' => :'String',
    :'first_attempted_at' => :'Time',
    :'last_attempted_at' => :'Time',
    :'completed_at' => :'Time',
    :'delivery_region' => :'String',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/zyphr/models/webhook_delivery.rb', line 250

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      msg_id == o.msg_id &&
      event_id == o.event_id &&
      event_type == o.event_type &&
      status == o.status &&
      attempts == o.attempts &&
      max_attempts == o.max_attempts &&
      next_attempt_at == o.next_attempt_at &&
      last_response_status == o.last_response_status &&
      latency_ms == o.latency_ms &&
      last_error == o.last_error &&
      first_attempted_at == o.first_attempted_at &&
      last_attempted_at == o.last_attempted_at &&
      completed_at == o.completed_at &&
      delivery_region == o.delivery_region &&
      created_at == o.created_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/zyphr/models/webhook_delivery.rb', line 381

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


273
274
275
# File 'lib/zyphr/models/webhook_delivery.rb', line 273

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



279
280
281
# File 'lib/zyphr/models/webhook_delivery.rb', line 279

def hash
  [id, msg_id, event_id, event_type, status, attempts, max_attempts, next_attempt_at, last_response_status, latency_ms, last_error, first_attempted_at, last_attempted_at, completed_at, delivery_region, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



223
224
225
226
227
# File 'lib/zyphr/models/webhook_delivery.rb', line 223

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



357
358
359
# File 'lib/zyphr/models/webhook_delivery.rb', line 357

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/zyphr/models/webhook_delivery.rb', line 363

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



351
352
353
# File 'lib/zyphr/models/webhook_delivery.rb', line 351

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



231
232
233
234
235
236
# File 'lib/zyphr/models/webhook_delivery.rb', line 231

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["pending", "delivering", "delivered", "failed", "exhausted"])
  return false unless status_validator.valid?(@status)
  true
end